// ImageData.h
//
// Header file for the CImageData class
//////////////////////////////////////////////

/*** 1.0129 PAT 21.12.98 NEW BITMAPS ***/

#ifndef IMAGEDATA
#define IMAGEDATA

#include <afx.h>
#include <afxwin.h>

// Include version info
#ifdef _ALIUSE
	#include "..\Versions\versions.h"
#else
	#include "versions.h"
#endif

// Class specific definitions
// Graphic types
#define IMAGE_TYPE_VECTOR		0
#define IMAGE_TYPE_RASTER		1
// Image formats
#define IMAGE_FORMAT_DONTCARE	0
#define IMAGE_FORMAT_VECTOR		1
#define IMAGE_FORMAT_RASTER		2
// Dither schemes
//// 1.0325 PAT 11.04.00 NONE DITHER SCHEME ////
//#define IMAGE_DITHER_DEFAULT	0
#define IMAGE_DITHER_NONE		0
//// 1.0325 ////////////////////////////////////
#define IMAGE_DITHER_BURKES		1
#define IMAGE_DITHER_BAYER		2
#define IMAGE_DITHER_FLOYD		3
// Resolution
#define IMAGE_RES_DEFAULT			200000;
#define IMAGE_RES_TYPE_DEFAULT		0
#define IMAGE_RES_NAME_DEFAULT		_T("DEFAULT")
#define IMAGE_RES_SCALE_DEFAULT		1000
#define IMAGE_RES_TYPE_DPI			1
#define IMAGE_RES_NAME_DPI			_T("DPI")
#define IMAGE_RES_SCALE_DPI			1000

// Vectorize
//// 1.0339 PAT 30.04.00 VECTORIZE BITMAPS ////
#define IMAGE_VECTORIZE_NUMTYPES	2

//#define IMAGE_VECTORIZE_DEFAULT		0
#define IMAGE_VECTORIZE_NONE		0
//// 1.0339 ///////////////////////////////////
#define IMAGE_VECTORIZE_DOTS		1
#define IMAGE_VECTORIZE_LINES		2
#define IMAGE_VECTORIZE_SEMILINES	3
#define IMAGE_VECTORIZE_SCANS		4
#define IMAGE_VECTORIZE_GRAYSCALE	5

// Corner
#define IMAGE_CORNER_NUM			4
#define IMAGE_CORNER_X				0
#define IMAGE_CORNER_Y				1
#define IMAGE_CORNER_BL				0
#define IMAGE_CORNER_TL				1
#define IMAGE_CORNER_TR				2
#define IMAGE_CORNER_BR				3

// Justification
#define IMAGE_JUST_BL				0
#define IMAGE_JUST_BC				1
#define IMAGE_JUST_BR				2
#define IMAGE_JUST_CL				3
#define IMAGE_JUST_CC				4
#define IMAGE_JUST_CR				5
#define IMAGE_JUST_TL				6
#define IMAGE_JUST_TC				7
#define IMAGE_JUST_TR				8

//// 1.0379 PAT 07.06.00 GRAYSCALE ////
/// 1.0352 DAN 1/15/01 ULS MARKER BITMAP MARKING ///
// Render Mode
const int IMAGE_RENDERMODE_NUMTYPES	=	4;

const int IMAGE_RENDERMODE_BW		=	0;	// Dithered monochrome
const int IMAGE_RENDERMODE_CTD		=	1;	// Connect-the-dots (vectors)
const int IMAGE_RENDERMODE_GS8		=	2;	// 8 bit Grayscale
const int IMAGE_RENDERMODE_NAT		=	3;	// Natural colors
////1.0352//////////////////////////////////////////
//// 1.0379 ///////////////////////////


class CImageData : public CObject
{
	DECLARE_SERIAL( CImageData )

// Attributes
public:
	UINT
		m_nVersion;		// Archive version
	CObject
		*m_pItem;		// Points to the item containing this data
	CString
		m_sRoot,		// The app's root directory
		m_sTemp;		// The app's temp directory
	CString
		m_sName;		// The file name of the image
	int
		m_nType,		// Indicates type of treatment(based on file extension)
		m_nFormat;		// Indicates current format of the image
	HANDLE
		m_hImage,		// The unadulterated image from the file
		m_hShowImage,	// Handle to the image that gets shown
		m_hMaskImage,	// Handle to the mask for the show image
		m_hPreMarkImage,// Handle to the pre-mark image (used to get rotation whitespace)
		m_hMarkImage;	// Handle to the image that gets marked
	int
		m_iNatH,		// The height of the original image in pixels
		m_iNatW;		// The width of the original image in pixels
	BOOL
		m_bRasBiDir,	// Indicates whether marking is bidirectional
		m_bRasVert,		// Indicates whether rasters are vertical or horizontal
		m_bGrayScale,	// Indicates whether BW or grayscale image is marked
		m_bNegative,	// Indicates whether the color scheme is inverted
		m_bRender;		// Indicates whether to calc new ShowImage or use old one
	int
		m_iDitherScheme;// Indicates dither method used
	long
		m_lRes;			// The marked image resolution
	int
		m_iResType;		// The units of the resolution
	int
		m_iVectorScheme;// Indicates the vectorization algorithm
	long
		m_alCorners[IMAGE_CORNER_NUM][2];	// The corners of the bitmap
	int
		m_iBrightAdjust;	// The adjustment to the birghtness level

	long
		m_lAdjX,
		m_lAdjY;


// Operators
public:
	// Contructor / Destructor
	CImageData(void);
	~CImageData(void);
	void Init(void);	// Initiallize
	void operator =( const CImageData& );
	BOOL operator ==( const CImageData& );
	void Serialize(CArchive& ar);

	void DeleteImage(HANDLE&);	// Closes and nullifies a image
	
	void ChooseVectorType(void);
	BOOL OpenDialog(void);
	BOOL OpenImage(void);
	BOOL RenderImage(RECT *);
	BOOL DrawShowImage(CDC *, RECT *);
	int GetDitherFlag(void);
	/*** 1.0165 PAT 21.04.99 FIXTURE ARRAY WITH RASTER ***/
	//void ComputeCorners(void);
	/*** 1.0165 ******************************************/
	void ComputeCorners(BOOL bNew = FALSE, long lX = 0, long lY = 0, long double ldA = 0.0, BOOL bBL = FALSE);
	void GetNatSize(void);
	void GetImageSize(long *, long *);
	BOOL MakeRaster(void);

	void GetNatSize(int *, int *);	// overload of above function
	HANDLE GetMarkDIB(void);
	int GetBitsOffset(LPBITMAPINFOHEADER);
	/*** 1.0165 PAT 21.04.99 FIXTURE ARRAY WITH RASTER ***/
	//BOOL RenderPreMarkImage(int, int);
	BOOL RenderPreMarkImage(int, int, long double);
	/*** 1.0165 ******************************************/
	void GetRotatedImageSize(int * = NULL, int * = NULL, long * = NULL,
							 long * = NULL, long double * = NULL);
	BOOL RenderMarkImage(int , int );


	//// 1.0325 PAT 11.04.00 NONE DITHER SCHEME ////
	BOOL IsMonochrome(HANDLE hImage);
	//// 1.0325 ////////////////////////////////////

	//// 1.0337 PAT 30.04.00 IMAGEDATA MARK DIB ////
	HANDLE
		m_hMarkDIB;
	LPBITMAPINFOHEADER
		m_lpMarkBIH;
	

	BOOL NewMarkDIB(void);
	void DeleteMarkDIB(void);
	LPBITMAPINFOHEADER GetMarkBIH(void);
	void SetModifiedFlag(void);
	void ClearModifiedFlag(void);
	BOOL IsModified(void);

protected:
	BOOL
		m_bModified;
	//// 1.0337 ////////////////////////////////////

	//// 1.0339 PAT 30.04.00 VECTORIZE BITMAPS ////
protected:
	long *
		m_pVecList;

public:
	int Vectorize(long lRunStartPix, long lPixX, long lPixY, long lDotSizeX, long lDotSizeY);
	void DeleteVecList(void);
	int GetBitsPerPixel(void);
	BOOL MarkWithVectors(void);
	long * GetVectorList(void);
	//// 1.0339 ///////////////////////////////////

	//// 1.0379 PAT 07.06.00 GRAYSCALE ////
protected:
	int
		m_iRenderMode;
public:
	int GetRenderMode(void);
	void SetRenderMode(int iMode);
	HANDLE ReduceColors(HANDLE hImage);
	BOOL IsGrayscale(void);
	int GetColorBits(HANDLE hImage);
	int GetColorDepth(HANDLE hImage);
	//// 1.0379 ///////////////////////////


	//// 1.0407 PAT 02.08.00 IMAGE DATA IN RASTER DIALOG ////
public:
	int GetStatistics(CString& sName, CString& sSize, CString& sColors, HANDLE hImage = NULL);	
	//// 1.0407 /////////////////////////////////////////////

	//// 1.0677 PAT 24.05.02 DATA MATRIX BITMAP ////
	//// 1.0721 PAT 13.11.02 RASTER BARCODE MEM FIX ////
	//	BOOL StartImage(void);
	BOOL StartImage(HANDLE hNewImage);
	//// 1.0721 ////////////////////////////////////////
	//// 1.0677 ////////////////////////////////////

	//// 1.0999 PAT 23.03.05 NEW COM FUNCTIONS ////
	void ClearImages(void);
	//// 1.0999 ///////////////////////////////////

	//// PS080515A NO-ROTATED CTD BITMAPS ////
	BOOL m_bVectorRotation;
	BOOL UseVectorRotation(void);
	//// PS080515A ///////////////////////////

};

#endif //IMAGEDATA