// LM45Share_Ver.h

// This file contains descriptions of the history of changes to 
// the CLM45Share class.

// All revision numbers here will begin with S (for Share)

// Pat Summers
// American LaserWare, Inc.
// 06 MAY 99

#ifndef LM45SHARE_VER
#define LM45SHARE_VER

/*** REV S000 - 19990506 - IN THE BEGINNING... ***/
// P. Summers - ALI
/*
	History begins here.
	Any versions of the software prior to this cannot be supported.
*/
const UINT LM45SHARE_VER_000	=	199905060;
/*** REV S000 ************************************/

/*** REV S001 - 19990606 - PROLASE-LIKE IO ***/
// P. Summers - ALI
/*
	The IO in the manager no longer references the IO like the
	old Miyachi LM45 software, but rather in a ProLase format.
	As such, the Ready, Marking, Done, and CounterUp outputs
	are general purpose and not tied to those functions.  Thus,
	ReadyLED is NOT tied to the same state as Ready, so a
	MarkProgReadLED variable is added to the shared memory.
	LM45Good variable is added to allow ProLase to NOT allow
	start signals, but also to NOT abort due to RI or shutter
	problems.

	Files modified:
	LM45Share.cpp
	LM45Share.h
	LM45Share_Constants.h

*/
const UINT LM45SHARE_VER_001	=	199906060;
/*** REV S001 ************************************/


/*** REV S002 - 19990610 - LAMP POWER LOCK ***/
// P. Summers - ALI
/*
	This rev is to avoid state conflicts and unknown and automatic
	hardware switching due to the guide beam and the lamp
	power.  It is though that the lamp can be on while the guide
	beam is on with the shutter open, but only it the lamp
	is at minimum power.  Thus, CLM45 will set and lock the
	power at minimum when the guide beam is switched on. This
	mod adds a flag to the shared data that indicates whether
	of not the lock is active.
	
	Files modified:
	LM45Share.cpp
	LM45Share.h
	LM45Share_Constants.h
*/
const UINT LM45SHARE_VER_002	=	199906100;
/*** REV S002 ********************************/

/*** REV S003 - 19990618 - NEW HARDWARE ACCESS RULES ***/
// P. Summers - ALI
/*
	This revision changes the code in the CanModifyHardware
	function.  Now, a Manager program ALWAYS has the ability to
	modify the hardware.  Other programs are prohibited during
	special routines (shutdown and startup and when a process
	promotes itself to BOSS status).

	Files modified:
	LM45Share.cpp
*/
const UINT LM45SHARE_VER_003	=	199906180;
/*** REV S003 ******************************************/

/*** REV S004 - 19990618 - MARK PROG MARKING NOW FLAG ***/
// P. Summers
/*
	A flag is added to the ShareData structure. m_bMarkProgMarkingActive
	indicates the state that the Mark Prog is currently marking
	a part.  (In ProLase, this flag is set after the start signal
	is received and until the post mark output is sent for each
	layer.  It is not an exact indicator of laser emission, on that
	possible emission can occur.)
	The purpose of the flag is to indicate to other programs that
	the settings should not be changed.  (e.g. turning the guide
	beam off between objects, allowing emission mid-layer)
	This flag is added rather than using m_bMarkProgLaserOn to avoid
	overloading the meaning of that flag.  They are the same for
	ProLase, but maybe not for others...

	Files modified:
	LM45Share_Constants.h
	LM45Share.cpp
	LM45Share.h
*/
const UINT LM45SHARE_VER_004	=	199906181;
/*** REV S004 *******************************************/


/*** REV S005 - 19990715 - BOARD FAULTY VARIABLE ***/
// P. Summers - ALI
/*
	A variable to indicate whether the process that
	initialized the hardware (the first one) found that
	the board did not respond properly is added to the
	shared memory structure:   m_bBoardFaulty

	Tied to
		REV L009
		
	Filed modified:
	LM45Share_Constants.h
	LM45Share.h
	LM45Share.cpp
*/
const UINT LM45SHARE_VER_005	=	199907150;
/*** REV S005 **************************************/

/*** REV S006 - 19990730 - INIT IN CONSTRUCTOR ***/
/*** REV S006 ************************************/
// P. Summers - ALI
/*
	Noticed that the destructor tests and destructs the MMF
	and other data through the Outit() function, always.
	However, the Init() is NOT called in the constructor!
	This is necessary as Init() will grab the MMF whether
	or not it is as yet needed. (ProLase only needs it
	with the LM45 driver.)  A 'null'ing version of the
	init code is placed in the constructor to ensure
	proper destructing.

	Files modified:
	LM45Share.cpp
*/
const UINT LM45SHARE_VER_006	=	199907300;

/*** Define the latest version ***/
const UINT LM45SHARE_VERSION	=	LM45SHARE_VER_006;

#define LM45SHARE_VERSION_RELEASE_NUMBER		_T("01.06.00")
#define LM45SHARE_VERSION_RELEASE_DATE			_T("30 JUL 1999")

#endif LM45SHARE_VER
