// LM50.h

// Header file for the CLM50 class.
//
// Pat Summers
// American Laserware, Inc.

//// REV L000 - 20000809 - IN THE BEGINNING... ////
// Converted from LM45...
//// REV L000 /////////////////////////////////////


//// REV L005 - 20020617- CALIBRATION ////
// Contains many changes from this rev that
// are NOT noted.
//// REV L005 ////////////////////////////

#ifndef	LM50
#define LM50

// Include all revision notes
#include "LM50_Ver.h"
// Include the definition of constants used by this class
// (excluding hardware IO)
#include "LM50_Constants.h"
// Include the definitions for the LM50 PC Control board
#include "LM50_Board.h"
// Include the header for members
#include "LM50Share.h"

#include "LM50CalTable.h"

// Define the class

class CLM50	: public CObject
{
public:
	// Version number for class
	UINT
		m_nVersion;
	// Constructor
	CLM50(void);
	// Destructor
	~CLM50(void);

	// Initalization for class
	void Init(BOOL bManager = FALSE);
	// Initalization of the hardware
	void InitBoard(void);

	// Determines if the address space is
	// used for input of output
	BOOL IsInputPort(WORD wAddr, UINT nBit = 0);
	// Custom Input / Output functions that
	// maintains the output port states in
	// m_wPort0xXXXX member variables
	// Using these i/o functions allows us
	// treat all ports as both read and write
	WORD Input(WORD wAddr, UINT nBit = 0);
	void Output(WORD wAddr, WORD wState);
	
	// Used for implementing I/O
	void SelectValue(int iChoice);
	void LatchValue(int iChoice);
	// Board status during ADC
	BOOL IsBusy(void);

	// Sharing
	CLM50Share
		m_LM50Share;
	BOOL CanModifySettings(void);

	// Cooling water
	BOOL IsWaterFlowOk(void);
	BOOL IsWaterLevelOk(void);
	BOOL IsWaterOverTemp(void);
	BOOL IsPumpOn(void);
	BOOL SetPumpPower(BOOL bOn);
	BOOL GetPumpPower(void);
	BOOL IsRefridgeratorOk(void);
	float GetWaterFlow(void);
	BOOL IsSolValveOpen(void);
	BOOL IsWaterUnderTemp(void);
	BOOL IsCompressorOn(void);
	BOOL SetCompressorPower(BOOL bOn);
	BOOL GetCompressorPower(void);
	
	// Oscillator
	BOOL IsShutterOpen(void);
	BOOL IsShutterClosed(void);
	BOOL SetShutter(BOOL bOpen);
	BOOL GetShutter(void);
	BOOL IsOscCoverOpen(void);
	BOOL IsOscLDLightOn(void);
	BOOL IsOscShutterLightOn(void);
	BOOL IsQSOverTemp(void);
	BOOL IsGuideBeamOn(void);
	BOOL SetGuideBeam(BOOL bOn);
	BOOL GetGuideBeam(void);
	WORD GetXGalvo(void);
	WORD GetYGalvo(void);
	WORD SetXGalvo(WORD wXPos);
	WORD SetYGalvo(WORD wYPos);
	BOOL SetPosition(WORD wXPos, WORD wYPos);

	// QSwitch Driver
	BOOL IsQsdOn(void);
	BOOL SetQSDPower(BOOL bOn);
	BOOL GetQSDPower(void);
	BOOL IsQsdVSWROK(void);
	BOOL IsQsdOverTemp(void);
// HFOutput
/*
	BOOL IsQsdHFOutOK(void);
*/
	BOOL IsCWModeOn(void);
	BOOL SetCWMode(BOOL bCW);
	BOOL GetCWMode(void);
	float GetQSFreq(void);
	BOOL SetQSFreq(float fFreq, float *pActual = NULL);
	float GetQSModFactor(void);
	BOOL SetQSModFactor(float fModFactor, float *pActual = NULL);
	BOOL IsGateOpen(void);
	BOOL SetQSDGate(BOOL bOn);
	BOOL GetQSDGate(void);

	// Unit
	BOOL IsUnitOn(void);
	BOOL SetUnitPower(BOOL bOn);
	BOOL GetUnitPower(void);
	
	// Power Supply
	BOOL IsLDOn(void);
	BOOL SetLDPower(BOOL bOn);
	BOOL GetLDPower(void);
	BOOL IsPSOverTemp(void);
	BOOL IsPSOverCurrent(void);
	BOOL IsPSVoltOk(void);
	BOOL IsPSCurrentLimitOk(void);
	float GetLDCurrent(void);
	float GetLDSetting(void);
	//// REV L002 - 20020408 - POWER RAMPING ////
	//	BOOL SetLDCurrent(float fCurr, float *pActual = NULL);
	BOOL SetLDCurrent(float fCurr, float *pActual);
	//// REV L002 ///////////////////////////////
	float GetLDSettingMax(void);
	BOOL SetLDSettingMax(float *pActual = NULL);
	float GetLDSettingMaxValue(void);
	BOOL SetLDSettingMaxValue(float fCurr, float *pActual = NULL);
	BOOL GetPSTroubleReset(void);
	BOOL SetPSTroubleReset(BOOL bReset);

	void ResetPS(void);

	// Panel
	BOOL IsKeyOn(void);
	BOOL IsEMStopOn(void);
	BOOL IsRemoteInterlockOn(void);
	BOOL IsMainCoverOpen(void);
	BOOL IsPanelResetPressed(void);
	BOOL IsPanelStartPressed(void);
	BOOL IsPanelStopPressed(void);

	// LEDs
	BOOL IsPanelReadyLEDOn(void);
	BOOL SetPanelReadyLED(BOOL bOn);
	BOOL IsPanelTroubleLEDOn(void);
	BOOL SetPanelTroubleLED(BOOL bOn);
	BOOL IsPanelLaserLEDOn(void);
	BOOL SetPanelLaserLED(BOOL bOn);

	// External
	BOOL IsExtControlOn(void);
	BOOL IsExtResetPressed(void);
	BOOL IsExtStartPressed(void);
	BOOL IsExtStopPressed(void);
	unsigned char GetExtScheduleNumber(void);
	BOOL IsExtScheduleParityOdd(void);
	BOOL IsExtShutterOpenPressed(void);
	BOOL IsExtLDOnPressed(void);
	BOOL IsExtCounterResetPressed(void);
	BOOL IsExtCounterStopPressed(void);
	BOOL GetExtMarkingReady(void);
	BOOL SetExtMarkingReady(BOOL bOn);
	BOOL GetExtMarkingNow(void);
	BOOL SetExtMarkingNow(BOOL bOn);
	BOOL GetExtMarkingDone(void);
	BOOL SetExtMarkingDone(BOOL bOn);
	BOOL GetExtTrouble(void);
	BOOL SetExtTrouble(BOOL bOn);
	BOOL GetExtCounterUp(void);
	BOOL SetExtCounterUp(BOOL bOn);

	// Board
	BOOL EnableDAC(BOOL bOn);

	// ADC
	void GetAllADCValues(float *pFlow, float *pCurr);
protected:
	int
		m_iADCSamples;
	long
		m_lADCTimeFlow,
		m_lADCTimeCurrent;
public:
	int SetADCSamples(int iSamples);
	long GetADCTimeFlow(void);
	long GetADCTimeCurrent(void);
	
	// Initialization of the LM50 board
	BOOL SetInitialState(void);
	
	// Unit/type conversion
	float WordToDegrees(WORD wValue);
	WORD DegreesToWord(float fDegrees);
	float WordToOhms(WORD wValue);
	WORD OhmsToWord(float fOhms);
	float WordToFlowRate(WORD wValue);
	WORD FlowRateToWord(float fDegrees);
	float WordToAmps(WORD wValue);
	float WordToAmpsADC(WORD wValue);
	WORD AmpsToWord(float fAmps);
	float WordToMaxAmps(WORD wValue);
	WORD MaxAmpsToWord(float fAmps);
	float WordToHertz(WORD wValue);
	WORD HertzToWord(float fHertz);
	float WordToModFactor(WORD wValue);
	WORD ModFactorToWord(float fModFactor);

	BYTE GetGPOutputValue(void);
	BYTE GetGPInputValue(void);

	BOOL WaitForMinLDCurrent(int iTimeout = 10);

//// REV L002 - 20020408 - POWER RAMPING ////
protected:
	BOOL
		m_bPSLDChanging;
public:
	BOOL GetRampLDCurrentFlag(void);
	void SetRampLDCurrentFlag(BOOL bFlag);
	double GetRampLDCurrentDelay(void);
	void SetRampLDCurrentDelay(double dDelay);

	BOOL SetLDCurrent(float fCurr, float *pActual, BOOL bRamp, BOOL bDisplay);
//// REV L002 ///////////////////////////////

	//// REV L003 - 20020409 - SIMMER CURRENT ////
	long double GetTimeOfLastEvent(void);
	void SetTimeOfLastEvent(void);
	//// REV L003 ////////////////////////////////

	//// REV L004 - 20020513 - ADC SAMPLING CHANGE ////
	WORD
		m_wADCSamplesLDCurrent[LM50_SPEC_ADC_SAMPLES_LDCURRENT];
	int
		m_iADCIndexLDCurrent;
	float SampleLDCurrent(void);
	void ClearADCSamplesLDCurrent(void);

	WORD
		m_wADCSamplesWaterFlow[LM50_SPEC_ADC_SAMPLES_WATERFLOW];
	int
		m_iADCIndexWaterFlow;
	float SampleWaterFlow(void);
	void ClearADCSamplesWaterFlow(void);

	//// REV L004 /////////////////////////////////////

	BOOL SetLDCurrentBits(int iCurr);

protected:
	CLM50CalTable
		m_CalTable;
	double
		m_adCalibrationData[LM50CAL_TABLE_MAX];
	double
		m_dCalCurrentGoal;
public:
	BOOL GetCalibrationFlag(void);
	void SetCalibrationFlag(BOOL bOn);
	double GetCalibrationTolerance(void);
	void SetCalibrationTolerance(double dAmps);
	double GetCalibrationMaxDelay(void);
	void SetCalibrationMaxDelay(double dSeconds);
	double GetCalibrationCurrentGoal(void);
	void SetCalibrationCurrentGoal(double dGoal);
	CLM50CalTable * GetCalibrationTable(void);
	void SetCalibrationTable(CLM50CalTable *pTable);
	void GetCalibrationData(double *pData);
	void SetCalibrationData(double *pData);

	WORD AmpsToWordCalibrated(double dCurr, double *pGoal);
	double WordToAmpsADCCorrected(WORD wValue);
	void SettlePSLD(void);

	//// REV L007 - 20020922 - MAX CURRENT LIMIT ////
	BOOL SetLDCurrentSafe(float fCurr, float *pActual);
	BOOL SetLDCurrentSafe(float fCurr, float *pActual, BOOL bRamp, BOOL bDisplay);
	//// REV L007 ///////////////////////////////////

};

#endif	// LM50


