// LM50_board.h

// This file contains definitions of constants used
// to interface with the LM50 PC Control board
// 
// Definitions based information sent by
// Greg Bates of Unitek Miyachi
//
// Pat Summers
// American LaserWare, Inc.

//// REV L000 - 20000809 - IN THE BEGINNING... ////
// Converted from LM45...
//// REV L000 /////////////////////////////////////

#ifndef LM50_BOARD
#define LM50_BOARD

// INPUT PORTS ////////////////////////////////////////////////////////
const unsigned short	LM50_PORT_0200						=	0x0200;
const unsigned short	LM50_PORT_021A						=	0x021a;
const unsigned short	LM50_PORT_0220						=	0x0220;
const unsigned short	LM50_PORT_0222						=	0x0222;	

// OUTPUT PORTS ///////////////////////////////////////////////////////
const unsigned short	LM50_PORT_0202						=	0x0202;
const unsigned short	LM50_PORT_0204						=	0x0204;
const unsigned short	LM50_PORT_0218						=	0x0218;
const unsigned short	LM50_PORT_021C						=	0x021c;
const unsigned short	LM50_PORT_0224						=	0x0224;

// All monitors, gages, etc. below are arranged
// by type then functional groups rather than by port.
// For clarity, the following nomenclature is adopted:
// 
// Type:
// _STATUS_ indicates an input flag bit
// _GAGE_	indicates an input multibit value
// _SWITCH_	indicates a single bit output
// _VALUE_	indicates a multibit output
// Grouping:
// _BOARD_	indicates an item internal to the LM50 PC control board
// _WATER_	indicates an item in the water cooling system
// _OSC_	indicates an item in the oscillator case
// _QSD_	indicates an item in the Q-Switch driver
// _PS_		indicates an item in the power supply
// _PANEL_	indicates an item on the LM50 control panel
// _EXT_	indicates an item is from external sources


// STATUS ///////////////////////////////////////////////////////////////////
const unsigned short	LM50_BOARD_BUSY_STATUS_ADDR			=	LM50_PORT_0222;
const unsigned short	LM50_BOARD_BUSY_STATUS_MASK			=	0x0040;	// bit 6
const unsigned short	LM50_BOARD_BUSY_STATUS_BUSY			=	0;
const unsigned short	LM50_BOARD_BUSY_STATUS_OK			=	1;

const unsigned short	LM50_WATER_FLOW_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_WATER_FLOW_STATUS_MASK			=	0x1000;	// bit 12
const unsigned short	LM50_WATER_FLOW_STATUS_NG			=	0;
const unsigned short	LM50_WATER_FLOW_STATUS_OK			=	1;

const unsigned short	LM50_WATER_LEVEL_STATUS_ADDR		=	LM50_PORT_021A;
const unsigned short	LM50_WATER_LEVEL_STATUS_MASK		=	0x0080;	// bit 7	change
const unsigned short	LM50_WATER_LEVEL_STATUS_NG			=	1;
const unsigned short	LM50_WATER_LEVEL_STATUS_OK			=	0;

const unsigned short	LM50_WATER_FRIDGE_STATUS_ADDR		=	LM50_PORT_021A;
const unsigned short	LM50_WATER_FRIDGE_STATUS_MASK		=	0x2000;	// bit 13
const unsigned short	LM50_WATER_FRIDGE_STATUS_NG			=	1;
const unsigned short	LM50_WATER_FRIDGE_STATUS_OK			=	0;

const unsigned short	LM50_WATER_TEMPHIGH_STATUS_ADDR		=	LM50_PORT_021A;
const unsigned short	LM50_WATER_TEMPHIGH_STATUS_MASK		=	0x4000;	// bit 14
const unsigned short	LM50_WATER_TEMPHIGH_STATUS_NG		=	1;
const unsigned short	LM50_WATER_TEMPHIGH_STATUS_OK		=	0;

const unsigned short	LM50_WATER_TEMPLOW_STATUS_ADDR		=	LM50_PORT_021C;
const unsigned short	LM50_WATER_TEMPLOW_STATUS_MASK		=	0x1000;	// bit 12
const unsigned short	LM50_WATER_TEMPLOW_STATUS_NG		=	1;
const unsigned short	LM50_WATER_TEMPLOW_STATUS_OK		=	0;

const unsigned short	LM50_WATER_VALVE_STATUS_ADDR		=	LM50_PORT_021A;
const unsigned short	LM50_WATER_VALVE_STATUS_MASK		=	0x0020;	// bit 5	change due to empiracal evidence
const unsigned short	LM50_WATER_VALVE_STATUS_NG			=	1;
const unsigned short	LM50_WATER_VALVE_STATUS_OK			=	0;

const unsigned short	LM50_OSC_SHUTTEROPEN_STATUS_ADDR	=	LM50_PORT_0220;
const unsigned short	LM50_OSC_SHUTTEROPEN_STATUS_MASK	=	0x0200;	// bit 9
const unsigned short	LM50_OSC_SHUTTEROPEN_STATUS_NO		=	1;
const unsigned short	LM50_OSC_SHUTTEROPEN_STATUS_YES		=	0;

const unsigned short	LM50_OSC_SHUTTERCLOSED_STATUS_ADDR	=	LM50_PORT_0220;
const unsigned short	LM50_OSC_SHUTTERCLOSED_STATUS_MASK	=	0x0400;	// bit 10
const unsigned short	LM50_OSC_SHUTTERCLOSED_STATUS_NO	=	1;
const unsigned short	LM50_OSC_SHUTTERCLOSED_STATUS_YES	=	0;

const unsigned short	LM50_OSC_COVER_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_OSC_COVER_STATUS_MASK			=	0x0008;	// bit 3
const unsigned short	LM50_OSC_COVER_STATUS_NG			=	1;
const unsigned short	LM50_OSC_COVER_STATUS_OK			=	0;

const unsigned short	LM50_OSC_QSWITCHTEMP_STATUS_ADDR	=	LM50_PORT_021A;
const unsigned short	LM50_OSC_QSWITCHTEMP_STATUS_MASK	=	0x0800;	// bit 11
const unsigned short	LM50_OSC_QSWITCHTEMP_STATUS_NG		=	0;
const unsigned short	LM50_OSC_QSWITCHTEMP_STATUS_OK		=	1;

const unsigned short	LM50_OSC_LDLIGHT_STATUS_ADDR		=	LM50_PORT_0220;
const unsigned short	LM50_OSC_LDLIGHT_STATUS_MASK		=	0x1000;	// bit 12
const unsigned short	LM50_OSC_LDLIGHT_STATUS_OFF			=	0;
const unsigned short	LM50_OSC_LDLIGHT_STATUS_ON			=	1;

const unsigned short	LM50_OSC_SHUTTERLIGHT_STATUS_ADDR	=	LM50_PORT_0220;
const unsigned short	LM50_OSC_SHUTTERLIGHT_STATUS_MASK	=	0x2000;	// bit 13
const unsigned short	LM50_OSC_SHUTTERLIGHT_STATUS_OFF	=	0;
const unsigned short	LM50_OSC_SHUTTERLIGHT_STATUS_ON		=	1;

const unsigned short	LM50_QSD_DRIVER_STATUS_ADDR			=	LM50_PORT_0222;
const unsigned short	LM50_QSD_DRIVER_STATUS_MASK			=	0x2000;	// bit 13
const unsigned short	LM50_QSD_DRIVER_STATUS_OFF			=	1;
const unsigned short	LM50_QSD_DRIVER_STATUS_ON			=	0;

const unsigned short	LM50_QSD_VSWR_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_QSD_VSWR_STATUS_MASK			=	0x0100;	// bit 8
const unsigned short	LM50_QSD_VSWR_STATUS_NG				=	0;
const unsigned short	LM50_QSD_VSWR_STATUS_OK				=	1;

const unsigned short	LM50_QSD_TEMP_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_QSD_TEMP_STATUS_MASK			=	0x0200;	// bit 9
const unsigned short	LM50_QSD_TEMP_STATUS_NG				=	0;
const unsigned short	LM50_QSD_TEMP_STATUS_OK				=	1;

// HFOutput
/*
const unsigned short	LM50_QSD_HFOUT_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_QSD_HFOUT_STATUS_MASK			=	0x0400;	// bit 10
const unsigned short	LM50_QSD_HFOUT_STATUS_NG			=	0;
const unsigned short	LM50_QSD_HFOUT_STATUS_OK			=	1;
*/

const unsigned short	LM50_PS_VOLT_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_PS_VOLT_STATUS_MASK			=	0x0040;	// bit 6
const unsigned short	LM50_PS_VOLT_STATUS_NG 				=	0;
const unsigned short	LM50_PS_VOLT_STATUS_OK				=	1;

const unsigned short	LM50_PS_TEMP_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_PS_TEMP_STATUS_MASK			=	0x0001;	// bit 0
const unsigned short	LM50_PS_TEMP_STATUS_NG				=	0;
const unsigned short	LM50_PS_TEMP_STATUS_OK				=	1;

const unsigned short	LM50_PS_CURRENT_STATUS_ADDR			=	LM50_PORT_021A;
const unsigned short	LM50_PS_CURRENT_STATUS_MASK			=	0x0002;	// bit 1
const unsigned short	LM50_PS_CURRENT_STATUS_NG			=	0;
const unsigned short	LM50_PS_CURRENT_STATUS_OK			=	1;

const unsigned short	LM50_PANEL_KEY_STATUS_ADDR			=	LM50_PORT_0222;
const unsigned short	LM50_PANEL_KEY_STATUS_MASK			=	0x1000;	// bit 12
const unsigned short	LM50_PANEL_KEY_STATUS_OFF			=	1;
const unsigned short	LM50_PANEL_KEY_STATUS_ON			=	0;

const unsigned short	LM50_PANEL_MAINCOVER_STATUS_ADDR	=	LM50_PORT_021A;
const unsigned short	LM50_PANEL_MAINCOVER_STATUS_MASK	=	0x0004;	// bit 2
const unsigned short	LM50_PANEL_MAINCOVER_STATUS_NG		=	1;
const unsigned short	LM50_PANEL_MAINCOVER_STATUS_OK		=	0;

const unsigned short	LM50_PANEL_REMOTELOCK_STATUS_ADDR	=	LM50_PORT_021A;
const unsigned short	LM50_PANEL_REMOTELOCK_STATUS_MASK	=	0x0010;	// bit 4
const unsigned short	LM50_PANEL_REMOTELOCK_STATUS_NG		=	1;
const unsigned short	LM50_PANEL_REMOTELOCK_STATUS_OK		=	0;

const unsigned short	LM50_PANEL_TROUBLERESET_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_PANEL_TROUBLERESET_STATUS_MASK	=	0x0200;	// bit 9
const unsigned short	LM50_PANEL_TROUBLERESET_STATUS_OFF	=	1;
const unsigned short	LM50_PANEL_TROUBLERESET_STATUS_ON	=	0;

const unsigned short	LM50_PANEL_MARKINGSTART_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_PANEL_MARKINGSTART_STATUS_MASK	=	0x0100;	// bit 8
const unsigned short	LM50_PANEL_MARKINGSTART_STATUS_OFF	=	1;
const unsigned short	LM50_PANEL_MARKINGSTART_STATUS_ON	=	0;

const unsigned short	LM50_PANEL_MARKINGSTOP_STATUS_ADDR	=	LM50_PORT_0220;
const unsigned short	LM50_PANEL_MARKINGSTOP_STATUS_MASK	=	0x8000;	// bit 15
const unsigned short	LM50_PANEL_MARKINGSTOP_STATUS_OFF	=	1;
const unsigned short	LM50_PANEL_MARKINGSTOP_STATUS_ON	=	0;

const unsigned short	LM50_PANEL_EMSTOP_STATUS_ADDR		=	LM50_PORT_021A;
const unsigned short	LM50_PANEL_EMSTOP_STATUS_MASK		=	0x8000;	// bit 15
const unsigned short	LM50_PANEL_EMSTOP_STATUS_NG			=	0;
const unsigned short	LM50_PANEL_EMSTOP_STATUS_OK			=	1;

const unsigned short	LM50_EXT_SCHEDPARITY_STATUS_ADDR	=	LM50_PORT_0220;
const unsigned short	LM50_EXT_SCHEDPARITY_STATUS_MASK	=	0x0100;	// bit 8
const unsigned short	LM50_EXT_SCHEDPARITY_STATUS_OFF		=	1;
const unsigned short	LM50_EXT_SCHEDPARITY_STATUS_ON		=	0;

const unsigned short	LM50_EXT_MARKINGSTOP_STATUS_ADDR	=	LM50_PORT_0220;
const unsigned short	LM50_EXT_MARKINGSTOP_STATUS_MASK	=	0x8000;	// bit 15
const unsigned short	LM50_EXT_MARKINGSTOP_STATUS_OFF		=	0;
const unsigned short	LM50_EXT_MARKINGSTOP_STATUS_ON		=	1;

const unsigned short	LM50_EXT_MARKINGSTART_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_EXT_MARKINGSTART_STATUS_MASK	=	0x0001;	// bit 0
const unsigned short	LM50_EXT_MARKINGSTART_STATUS_OFF	=	1;
const unsigned short	LM50_EXT_MARKINGSTART_STATUS_ON		=	0;

const unsigned short	LM50_EXT_TROUBLERESET_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_EXT_TROUBLERESET_STATUS_MASK	=	0x0002;	// bit 1
const unsigned short	LM50_EXT_TROUBLERESET_STATUS_OFF	=	1;
const unsigned short	LM50_EXT_TROUBLERESET_STATUS_ON		=	0;

const unsigned short	LM50_EXT_EXTCONTROL_STATUS_ADDR		=	LM50_PORT_0222;
const unsigned short	LM50_EXT_EXTCONTROL_STATUS_MASK		=	0x0004;	// bit 2
const unsigned short	LM50_EXT_EXTCONTROL_STATUS_EXT		=	0;
const unsigned short	LM50_EXT_EXTCONTROL_STATUS_PANEL	=	1;

const unsigned short	LM50_EXT_SHUTTEROPEN_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_EXT_SHUTTEROPEN_STATUS_MASK	=	0x0008;	// bit 3
const unsigned short	LM50_EXT_SHUTTEROPEN_STATUS_OFF		=	1;
const unsigned short	LM50_EXT_SHUTTEROPEN_STATUS_ON		=	0;

const unsigned short	LM50_EXT_COUNTERSTOP_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_EXT_COUNTERSTOP_STATUS_MASK	=	0x0010;	// bit 4
const unsigned short	LM50_EXT_COUNTERSTOP_STATUS_OFF		=	1;
const unsigned short	LM50_EXT_COUNTERSTOP_STATUS_ON		=	0;

const unsigned short	LM50_EXT_LDON_STATUS_ADDR			=	LM50_PORT_0222;
const unsigned short	LM50_EXT_LDON_STATUS_MASK			=	0x0020;	// bit 5
const unsigned short	LM50_EXT_LDON_STATUS_OFF			=	1;
const unsigned short	LM50_EXT_LDON_STATUS_ON				=	0;

const unsigned short	LM50_EXT_COUNTERRESET_STATUS_ADDR	=	LM50_PORT_0222;
const unsigned short	LM50_EXT_COUNTERRESET_STATUS_MASK	=	0x0080;	// bit 7
const unsigned short	LM50_EXT_COUNTERRESET_STATUS_OFF	=	1;
const unsigned short	LM50_EXT_COUNTERRESET_STATUS_ON		=	0;

// GAGES /////////////////////////////////////////////////////////////////////////
//	const unsigned short	LM50_WATER_FLOW_GAGE_ADDR			=	LM50_PORT_0200;
//	const unsigned short	LM50_WATER_FLOW_GAGE_MASK			=	0x03ff;	// bits 0-11
//	const unsigned short	LM50_WATER_FLOW_GAGE_MIN			=	0X0000;	// 1 per min
//	const unsigned short	LM50_WATER_FLOW_GAGE_MAX			=	0X03ff;	// 10 per min
const unsigned short	LM50_WATER_FLOW_GAGE_ADDR			=	LM50_PORT_0200;
const unsigned short	LM50_WATER_FLOW_GAGE_MASK			=	0x0fff;	// bits 0-11
const unsigned short	LM50_WATER_FLOW_GAGE_MIN			=	0X0000;	// 1 per min
const unsigned short	LM50_WATER_FLOW_GAGE_MAX			=	0X0fff;	// 10 per min

const unsigned short	LM50_PS_LDCURRENT_GAGE_ADDR			=	LM50_PORT_0200;
const unsigned short	LM50_PS_LDCURRENT_GAGE_MASK			=	0x0fff;	// bits 0-11
const unsigned short	LM50_PS_LDCURRENT_GAGE_MIN			=	0x0000;	// 0 Amp
const unsigned short	LM50_PS_LDCURRENT_GAGE_MAX			=	0x0fff;	// 50 Amp

const unsigned short	LM50_EXT_SCHEDNUMBER_GAGE_ADDR		=	LM50_PORT_0220;
const unsigned short	LM50_EXT_SCHEDNUMBER_GAGE_MASK		=	0x00ff;	// bits 0-7
const unsigned short	LM50_EXT_SCHEDNUMBER_GAGE_MIN		=	0x0000;	// 0
const unsigned short	LM50_EXT_SCHEDNUMBER_GAGE_MAX		=	0x00ff;	// 255

// SWITCHES /////////////////////////////////////////////////////////////////// 
const unsigned short	LM50_BOARD_DACENABLE_SWITCH_ADDR	=	LM50_PORT_021C;
const unsigned short	LM50_BOARD_DACENABLE_SWITCH_MASK	=	0x0040;	// bit 6
const unsigned short	LM50_BOARD_DACENABLE_SWTICH_OFF		=	1;
const unsigned short	LM50_BOARD_DACENABLE_SWITCH_ON		=	0;

const unsigned short	LM50_BOARD_UNIT_SWITCH_ADDR			=	LM50_PORT_021C;
const unsigned short	LM50_BOARD_UNIT_SWITCH_MASK			=	0x0400; // bit 10
const unsigned short	LM50_BOARD_UNIT_SWITCH_OFF			=	0;
const unsigned short	LM50_BOARD_UNIT_SWITCH_ON			=	1;

const unsigned short	LM50_WATER_PUMP_SWITCH_ADDR			=	LM50_PORT_0218;
const unsigned short	LM50_WATER_PUMP_SWITCH_MASK			=	0x8000;	// bit 15
const unsigned short	LM50_WATER_PUMP_SWITCH_OFF			=	0;
const unsigned short	LM50_WATER_PUMP_SWITCH_ON			=	1;

const unsigned short	LM50_WATER_COMPRESSOR_SWITCH_ADDR	=	LM50_PORT_0224;
const unsigned short	LM50_WATER_COMPRESSOR_SWITCH_MASK	=	0x8000;	// bit 15
const unsigned short	LM50_WATER_COMPRESSOR_SWITCH_OFF	=	0;
const unsigned short	LM50_WATER_COMPRESSOR_SWITCH_ON		=	1;

const unsigned short	LM50_OSC_SHUTTER_SWITCH_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_OSC_SHUTTER_SWITCH_MASK		=	0x4000;	// bit 14
const unsigned short	LM50_OSC_SHUTTER_SWITCH_OFF			=	0;
const unsigned short	LM50_OSC_SHUTTER_SWITCH_ON			=	1;

const unsigned short	LM50_OSC_GUIDEBEAM_SWITCH_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_OSC_GUIDEBEAM_SWITCH_MASK		=	0x2000;	// bit 13
const unsigned short	LM50_OSC_GUIDEBEAM_SWITCH_OFF		=	0;
const unsigned short	LM50_OSC_GUIDEBEAM_SWITCH_ON		=	1;

const unsigned short	LM50_QSD_DRIVER_SWITCH_ADDR			=	LM50_PORT_0218;
const unsigned short	LM50_QSD_DRIVER_SWITCH_MASK			=	0x1000;	// bit 12
const unsigned short	LM50_QSD_DRIVER_SWITCH_OFF			=	0;
const unsigned short	LM50_QSD_DRIVER_SWITCH_ON			=	1;

const unsigned short	LM50_QSD_MODE_SWITCH_ADDR			=	LM50_PORT_0218;
const unsigned short	LM50_QSD_MODE_SWITCH_MASK			=	0x2000;	// bit 13
const unsigned short	LM50_QSD_MODE_SWITCH_CW				=	0;
const unsigned short	LM50_QSD_MODE_SWITCH_QS				=	1;

const unsigned short	LM50_QSD_GATE_SWITCH_ADDR			=	LM50_PORT_0218;
const unsigned short	LM50_QSD_GATE_SWITCH_MASK			=	0x4000;	// bit 14
const unsigned short	LM50_QSD_GATE_SWITCH_OFF			=	0;
const unsigned short	LM50_QSD_GATE_SWITCH_ON				=	1;

const unsigned short	LM50_PS_LD_SWITCH_ADDR				=	LM50_PORT_021C;
const unsigned short	LM50_PS_LD_SWITCH_MASK				=	0x0010;	// bit 4
const unsigned short	LM50_PS_LD_SWITCH_OFF				=	0;
const unsigned short	LM50_PS_LD_SWITCH_ON				=	1;

const unsigned short	LM50_PS_TROUBLERESET_SWITCH_ADDR	=	LM50_PORT_021C;
const unsigned short	LM50_PS_TROUBLERESET_SWITCH_MASK	=	0x0008;	// bit 3
const unsigned short	LM50_PS_TROUBLERESET_SWITCH_OFF		=	0;
const unsigned short	LM50_PS_TROUBLERESET_SWITCH_ON		=	1;

const unsigned short	LM50_PANEL_READYLED_SWITCH_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_PANEL_READYLED_SWITCH_MASK		=	0x0100;	// bit 8
const unsigned short	LM50_PANEL_READYLED_SWITCH_OFF		=	0;
const unsigned short	LM50_PANEL_READYLED_SWITCH_ON		=	1;

const unsigned short	LM50_PANEL_LASERONLED_SWITCH_ADDR	=	LM50_PORT_0224;
const unsigned short	LM50_PANEL_LASERONLED_SWITCH_MASK	=	0x0200;	// bit 9
const unsigned short	LM50_PANEL_LASERONLED_SWITCH_OFF	=	0;
const unsigned short	LM50_PANEL_LASERONLED_SWITCH_ON		=	1;

const unsigned short	LM50_PANEL_TROUBLELED_SWITCH_ADDR	=	LM50_PORT_0224;
const unsigned short	LM50_PANEL_TROUBLELED_SWITCH_MASK	=	0x0400;	// bit 10
const unsigned short	LM50_PANEL_TROUBLELED_SWITCH_OFF	=	0;
const unsigned short	LM50_PANEL_TROUBLELED_SWITCH_ON		=	1;

const unsigned short	LM50_PANEL_GUIDEBEAMLED_SWITCH_ADDR	=	LM50_PORT_0224;
const unsigned short	LM50_PANEL_GUIDEBEAMLED_SWITCH_MASK	=	0x2000;	// bit 13
const unsigned short	LM50_PANEL_GUIDEBEAMLED_SWITCH_OFF	=	0;
const unsigned short	LM50_PANEL_GUIDEBEAMLED_SWITCH_ON	=	1;

const unsigned short	LM50_EXT_MARKINGREADY_SWITCH_ADDR	=	LM50_PORT_0224;
const unsigned short	LM50_EXT_MARKINGREADY_SWITCH_MASK	=	0x0002;	// bit 1
const unsigned short	LM50_EXT_MARKINGREADY_SWITCH_OFF	=	0;
const unsigned short	LM50_EXT_MARKINGREADY_SWITCH_ON		=	1;

const unsigned short	LM50_EXT_MARKINGNOW_SWITCH_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_EXT_MARKINGNOW_SWITCH_MASK		=	0x0004;	// bit 2
const unsigned short	LM50_EXT_MARKINGNOW_SWITCH_OFF		=	0;
const unsigned short	LM50_EXT_MARKINGNOW_SWITCH_ON		=	1;

const unsigned short	LM50_EXT_MARKINGDONE_SWITCH_ADDR	=	LM50_PORT_0224;
const unsigned short	LM50_EXT_MARKINGDONE_SWITCH_MASK	=	0x0008;	// bit 3
const unsigned short	LM50_EXT_MARKINGDONE_SWITCH_OFF		=	0;
const unsigned short	LM50_EXT_MARKINGDONE_SWITCH_ON		=	1;

const unsigned short	LM50_EXT_TROUBLE_SWITCH_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_EXT_TROUBLE_SWITCH_MASK		=	0x0010;	// bit 4
const unsigned short	LM50_EXT_TROUBLE_SWITCH_OFF			=	1;
const unsigned short	LM50_EXT_TROUBLE_SWITCH_ON			=	0;

const unsigned short	LM50_EXT_COUNTERUP_SWITCH_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_EXT_COUNTERUP_SWITCH_MASK		=	0x0020;	// bit 5
const unsigned short	LM50_EXT_COUNTERUP_SWITCH_OFF		=	0;
const unsigned short	LM50_EXT_COUNTERUP_SWITCH_ON		=	1;

// VALUES /////////////////////////////////////////////////////////////////////
const unsigned short	LM50_OSC_XGALVO_VALUE_ADDR			=	LM50_PORT_0202;
const unsigned short	LM50_OSC_XGALVO_VALUE_MIN			=	0x0000;
const unsigned short	LM50_OSC_XGALVO_VALUE_MAX			=	0x3fff;

const unsigned short	LM50_OSC_YGALVO_VALUE_ADDR			=	LM50_PORT_0204;
const unsigned short	LM50_OSC_YGALVO_VALUE_MIN			=	0x0000;
const unsigned short	LM50_OSC_YGALVO_VALUE_MAX			=	0x3fff;

const unsigned short	LM50_QSD_FREQ_VALUE_ADDR			=	LM50_PORT_0218;
const unsigned short	LM50_QSD_FREQ_VALUE_MASK			=	0x01ff;	// bits 0-8
const unsigned short	LM50_QSD_FREQ_VALUE_MIN				=	0x000A;	// 1 kHz
const unsigned short	LM50_QSD_FREQ_VALUE_MAX				=	0x01f4;	// 50 kHz

const unsigned short	LM50_QSD_MODFACTOR_VALUE_ADDR		=	LM50_PORT_0218;
const unsigned short	LM50_QSD_MODFACTOR_VALUE_MASK		=	0x01ff;	// bits 0-8
const unsigned short	LM50_QSD_MODFACTOR_VALUE_MIN		=	0x0000;	// 100%
const unsigned short	LM50_QSD_MODFACTOR_VALUE_MAX		=	0x0032;	// 50%

const unsigned short	LM50_PS_LDCURRENT_VALUE_ADDR		=	LM50_PORT_0218;
const unsigned short	LM50_PS_LDCURRENT_VALUE_MASK		=	0x00ff;	// bits 0-7
const unsigned short	LM50_PS_LDCURRENT_VALUE_MIN			=	0x0000;	// 5 Amp
const unsigned short	LM50_PS_LDCURRENT_VALUE_MAX			=	0x0096;	// 30 Amp

const unsigned short	LM50_PS_LDCURRENTMAX_VALUE_ADDR		=	LM50_PORT_0218;
const unsigned short	LM50_PS_LDCURRENTMAX_VALUE_MASK		=	0x00ff;	// bits 0-7
const unsigned short	LM50_PS_LDCURRENTMAX_VALUE_MIN		=	0x0000;	// 5 Amp
const unsigned short	LM50_PS_LDCURRENTMAX_VALUE_MAX		=	0x0096;	// 30 Amp

// ADDITIONAL ////////////////////////////////////////////////////////////////////

// Select - ions /////////////////////////////////////////////////////////////////
//const int				LM50_SELECT_WATER_TEMP				=	1;
const int				LM50_SELECT_WATER_FLOW				=	2;
const int				LM50_SELECT_PS_LDCURRENT			=	3;
const int				LM50_SELECT_QSD_FREQ				=	4;
const int				LM50_SELECT_QSD_MODFACTOR			=	5;
const int				LM50_SELECT_PS_LDSETTING			=	6;
const int				LM50_SELECT_PS_LDSETTINGMAX			=	7;

// Select addresses ///////////////////////////////////////////////////////////
//const unsigned short	LM50_SELECT_WATER_TEMP_ADDR			=	LM50_PORT_0224;	
const unsigned short	LM50_SELECT_WATER_FLOW_ADDR			=	LM50_PORT_0224;
const unsigned short	LM50_SELECT_PS_LDCURRENT_ADDR		=	LM50_PORT_0224;
const unsigned short	LM50_SELECT_QSD_FREQ_ADDR			=	LM50_PORT_021C;
const unsigned short	LM50_SELECT_QSD_MODFACTOR_ADDR		=	LM50_PORT_021C;
const unsigned short	LM50_SELECT_PS_LDSETTING_ADDR		=	LM50_PORT_021C;
const unsigned short	LM50_SELECT_PS_LDSETTINGMAX_ADDR	=	LM50_PORT_021C;

// Latch - es /////////////////////////////////////////////////////////////////
const int				LM50_LATCH_PS_LDSETTING				=	1;
const int				LM50_LATCH_QSD_FREQ					=	2;
const int				LM50_LATCH_QSD_MODFACTOR			=	3;
const int				LM50_LATCH_PS_LDSETTINGMAX			=	4;

// Latch addresses ////////////////////////////////////////////////////////////
const unsigned short	LM50_LATCH_PS_LDSETTING_ADDR		=	LM50_PORT_021C;
const unsigned short	LM50_LATCH_QSD_FREQ_ADDR			=	LM50_PORT_021C;
const unsigned short	LM50_LATCH_QSD_MODFACTOR_ADDR		=	LM50_PORT_021C;
const unsigned short	LM50_LATCH_PS_LDSETTINGMAX_ADDR		=	LM50_PORT_021C;

// Initial values /////////////////////////////////////////////////////////////
const BOOL				LM50_INIT_WATER_PUMP			=	FALSE;
const BOOL				LM50_INIT_OSC_GUIDEBEAM			=	FALSE;
const BOOL				LM50_INIT_OSC_SHUTTEROPEN		=	FALSE;
const unsigned short	LM50_INIT_OSC_POSITION			=	0x1fff;
const BOOL				LM50_INIT_QSD_DRIVER			=	FALSE;
const BOOL				LM50_INIT_QSD_MODE				=	FALSE;
const float				LM50_INIT_QSD_FREQ				=	6.0f;
const float				LM50_INIT_QSD_MODFACTOR			=	100.0f;
const float				LM50_INIT_PS_LDCURRENT			=	5.0f;
const float				LM50_INIT_PS_LDCURRENTMAX		=	27.0f;
const BOOL				LM50_INIT_PS_LDPOWER			=	FALSE;

#endif	// LM50_BOARD
