// LM50Share.h

// Header file for the CLM50Share class.
//
// Pat Summers
// American LaserWare, Inc.

#ifndef	LM50SHARE
#define LM50SHARE

//// REV S000 - 20000809 - IN THE BEGINNING... ////
// Converted from LM45...
//// REV S000 /////////////////////////////////////

// Include all revision notes
#include "LM50Share_Ver.h"
// Include definitions of constants used by this class
#include "LM50Share_Constants.h"

// Define the class
class CLM50Share : public CObject
{
public:
	// Version number for class
	UINT
		m_nVersion;
	// Constructor
	CLM50Share(void);
	// Destructor
	~CLM50Share(void);
	// Initalization for class
	BOOL Init(BOOL bManager = FALSE);
	// Clean up and disposal
	void Outit(void);

private:
	// Shared data
	LM50ShareData
		m_ShareData;
public:
	// References to shared memory
	HANDLE
		m_hShareFileMapping;
	LPVOID
		m_lpShareAddress;
	HANDLE
		m_hShareMutex;
	// Shared memory control
	int
		m_iShareID;
	BOOL
		m_bSharing,
		m_bIsManager,
		m_bTheBoss,
		m_bTheADCBoss;
	// Shared memory access
	void ShareIn(void);
	void ShareOut(void);
	void InitSharing(void);
	BOOL CanModifyHardware(void);
	int	AddRef(void);
	void DelRef(void);
	int AddManager(void);
	void DelManager(void);
	BOOL IsManaged();
	BOOL Promote(int iTimeOut = 1);
	void Demote(void);

	// Maintenance
	int GetCount(void);
	void SetCount(int iCount);
	int GetManCount(void);
	void SetManCount(int iCount);
	BOOL IsBoardInitDone(void);
	void SetBoardInitDone(BOOL bDone);
	// Access Control
	int GetBoss(void);
	void SetBoss(int iBoss);
	int GetADCBoss(void);
	void SetADCBoss(int iBoss);
	BOOL IsShuttingDown(void);
	void SetShuttingDown(BOOL bShuttingDown);
	BOOL IsStartingUp(void);
	void SetStartingUp(BOOL bStartingUp);
	// Ports
	WORD GetPort0202(void);
	void SetPort0202(WORD wData);
	WORD GetPort0204(void);
	void SetPort0204(WORD wData);
	WORD GetPort0218(void);
	void SetPort0218(WORD wData);
	WORD GetPort021C(void);
	void SetPort021C(WORD wData);
	WORD GetPort0224(void);
	void SetPort0224(WORD wData);
	// Gage values
	float GetWaterTemp(void);
	void SetWaterTemp(float fTemp);
	float GetWaterFlow(void);
	void SetWaterFlow(float fFlow);
	float GetPSLDCurrent(void);
	void SetPSLDCurrent(float fCurrent);
	// Settings
	float GetQSDFreqSetting(void);
	void SetQSDFreqSetting(float fSetting);
	float GetQSDModFactorSetting(void);
	void SetQSDModFactorSetting(float fSetting);
	float GetPSLDSetting(void);
	void SetPSLDSetting(float fSetting);
	float GetPSLDSettingMax(void);
	void SetPSLDSettingMax(float fSetting);
	float GetPSLDSettingMaxValue(void);
	void SetPSLDSettingMaxValue(float fSetting);
	//// REV S001 - 20020408 - POWER RAMPING ////
	WORD GetPSLDSettingWORD(void);
	void SetPSLDSettingWORD(WORD wSetting);
	//// REV S001 ///////////////////////////////

	// LM50
	int GetState(void);
	int SetState(int iState);
	int GetCurrState(void);
	int SetCurrState(int iState);
	BOOL GetLM50Ready(void);
	BOOL SetLM50Ready(BOOL bReady);
	BOOL IsLM50Ready(void);
	BOOL GetLM50Good(void);
	void SetLM50Good(BOOL bGood);
	BOOL IsLM50Good(void);
	BOOL GetAnyReset(void);
	void SetAnyReset(BOOL bReset);
	BOOL IsAnyReset(void);
	BOOL GetAnyStart(void);
	void SetAnyStart(BOOL bStart);
	BOOL IsAnyStart(void);
	BOOL GetAnyStop(void);
	void SetAnyStop(BOOL bStop);
	BOOL IsAnyStop(void);
	// Mark prog
	BOOL GetMarkProgSet(void);
	void SetMarkProgSet(BOOL bSet);
	BOOL IsMarkProgSet(void);
	BOOL GetMarkProgInMarkMode(void);
	void SetMarkProgInMarkMode(BOOL bMarkMode);
	BOOL IsMarkProgInMarkMode(void);
	BOOL GetMarkProgReady(void);
	void SetMarkProgReady(BOOL bReady);
	BOOL IsMarkProgReady(void);
	BOOL GetMarkProgMarking(void);
	void SetMarkProgMarking(BOOL bMarking);
	BOOL IsMarkProgMarking(void);
	BOOL GetMarkProgLaserOn(void);
	void SetMarkProgLaserOn(BOOL bOn);
	BOOL IsMarkProgLaserOn(void);
	BOOL GetMarkProgDone(void);
	void SetMarkProgDone(BOOL bDone);
	BOOL IsMarkProgDone(void);
	BOOL GetMarkProgCounterUp(void);
	void SetMarkProgCounterUp(BOOL bUp);
	BOOL IsMarkProgCounterUp(void);
	BOOL GetMarkProgAborted(void);
	void SetMarkProgAborted(BOOL bAbort);
	HWND GetMarkProgWindow(void);
	void SetMarkProgWindow(HWND hWindow);
	BOOL IsMarkProgWindow(void);
	BOOL IsMarkProgAborted(void);

	
	
	int GetSerialCounter(void);
	void SetSerialCounter(int iCount);
	int IncSerialCounter(void);
	unsigned short GetScheduleNumber(void);
	void SetScheduleNumber(unsigned short nNumber);

	BOOL GetMarkProgReadyLED(void);
	void SetMarkProgReadyLED(BOOL bReady);
	BOOL IsMarkProgReadyLED(void);

	BOOL GetLDPowerLocked(void);
	void SetLDPowerLocked(BOOL bLocked);
	BOOL IsLDPowerLocked(void);

	BOOL GetMarkProgMarkingActive(void);
	void SetMarkProgMarkingActive(BOOL bActive);
	BOOL IsMarkProgMarkingActive(void);

	BOOL GetBoardFaulty(void);
	void SetBoardFaulty(BOOL bFaulty);
	BOOL IsBoardFaulty(void);

	//// REV S001 - 20020408 - POWER RAMPING ////
	BOOL GetRampLDCurrentFlag(void);
	void SetRampLDCurrentFlag(BOOL bFlag);
	double GetRampLDCurrentDelay(void);
	void SetRampLDCurrentDelay(double dDelay);
	//// REV S001 ///////////////////////////////

	//// REV S002 - 20020409 - SIMMER CURRENT ////
	long double GetTimeLastEvent(void);
	void SetTimeLastEvent(long double ldTime);
	//// REV S002 ////////////////////////////////

	BOOL GetCalibrationFlag(void);
	void SetCalibrationFlag(BOOL bOn);
	double GetCalibrationTolerance(void);
	void SetCalibrationTolerance(double dAmps);
	double GetCalibrationMaxDelay(void);
	void SetCalibrationMaxDelay(double dSeconds);
	void GetCalibrationData(double *pData);
	void SetCalibrationData(double *pData);
	double GetCalibrationDatum(int iIndex);
	void SetCalibrationDatum(int iIndex, double dDatum);

	//// REV S004 - 20080318 - MT RACE UPDATE ////
	int m_iMutexGrabs;
	//// REV S004 ////////////////////////////////
};

#endif	// LM50


