// LM50Share_Constants.h

// This file contains definitions of constants used
// in the CLM50Share class
//
// Pat Summers
// American LaserWare, Inc.

//// REV S000 - 20000809 - IN THE BEGINNING... ////
// Converted from LM45...
//// REV S000 /////////////////////////////////////

#ifndef LM50SHARE_CONSTANTS
#define LM50SHARE_CONSTANTS

//// REV S003 - 20020409 - CALIBRRATION ////
#include "LM50Cal_Constants.h"
//// REV S003 ////////////////////////////////

// Shared memory
#define		LM50_SHARING_MAPNAME		_T("LM50_ShareFileMapping")

// Single access
#define		LM50_SHARING_MUTEXNAME		_T("LM50_ShareMutex")
// Tomo
//	const int	LM50_SHARING_MUTEXTIMEOUT	=	10;	// in milliseconds
const int	LM50_SHARING_MUTEXTIMEOUT	=	1000;	// in milliseconds

typedef struct LM50ShareDataTag
{
	// Maintenance
	int
		m_iCount,
		m_iManCount;
	BOOL
		m_bBoardInitDone;
	BOOL
		m_bBoardFaulty;
	// Access control
	int
		m_iBoss,
		m_iADCBoss;
	BOOL
		m_bShuttingDown,
		m_bStartingUp;
	// Current state
	int
		m_iState,
		m_iCurrState;
	WORD
		m_wPort0202,
		m_wPort0204,
		m_wPort0218,
		m_wPort021C,
		m_wPort0224;
	float
		m_fWaterTemp,
		m_fWaterFlow,
		m_fPSLDCurrent;
	float
		m_fQSDFreqSetting,
		m_fQSDModFactorSetting,
		m_fPSLDSetting,
		m_fPSLDSettingMax,
		m_fPSLDSettingMaxValue;
	unsigned short
		m_nScheduleNumber;
	int
		m_iSerialCounter;
	// Synchronization
	BOOL
		m_bLM50Ready,
		m_bAnyReset,
		m_bAnyStart,
		m_bAnyStop;
	BOOL
		m_bLM50Good;
/*
	m_bLM50Ready					- Indicates that the LM50 is in the Ready state.
	m_bLM50Good						- Indicates that the LM50 can't start marking, but shouldn't abort
	m_bAnyReset						- A valid reset was received (Panel, Ext, Dialog)
	m_bAnyStart						- A valid stop was receiced (Panel, Ext, Dialog)
	m_bAnyStop						- A valid stop was received (Panel, Ext, Dialog
*/
	BOOL
		m_bMarkProgSet,
		m_bMarkProgInMarkMode,
		m_bMarkProgReady,
		m_bMarkProgMarking,
		m_bMarkProgLaserOn,
		m_bMarkProgDone,
		m_bMarkProgCounterUp,
		m_bMarkProgAborted;
	HWND
		m_hMarkProgWindow;

	BOOL
		m_bMarkProgReadyLED;
/*
	m_bMarkProgSet					- Mark prog has a document loaded
	m_bMarkProgInMarkMode			- Mark prog is in a marking mode (rahter than editing)
	m_bMarkProgReady				- Mark prog output bit 7
	m_bMarkProgReadLED				- Mark prog is ready to accept a start signal
	m_bMarkProgMarking				- Mark prog output bit 6
	m_bMarkProgLaserOn				- Mark prog may turn the laser on
	m_bMarkProgDone					- Mark prog output bit 5
	m_bMarkProgCounterUp			- Mark prog output bit 4
	m_bMarkProgAborted				- Mark prog has aborted a mark
	m_bMarkProgMarkingActive		- Mark prog is currently marking
	m_hMarkProgWindow				- Mark prog main window handle
*/

	BOOL
		m_bLDPowerLocked;

	BOOL
		m_bMarkProgMarkingActive;

	//// REV S001 - 20020408 - POWER RAMPING ////
	BOOL
		m_bRampLDCurrentFlag;
	double
		m_dRampLDCurrentDelay;
	WORD
		m_wPSLDSetting;
	//// REV S001 ///////////////////////////////
	
	//// REV S002 - 20020409 - SIMMER CURRENT ////
	long double
		m_ldTimeLastEvent;
	//// REV S002 ////////////////////////////////


	BOOL
		m_bCalibrationFlag;
	double
		m_dCalibrationTolerance,
		m_dCalibrationMaxDelay;
	double
		m_adCalibrationData[LM50CAL_TABLE_MAX+1];


} LM50ShareData;

// IPC Messages
const UINT	LM50_IPCMSG_IGNORE						=	0;
const UINT	LM50_IPCMSG_STARTSIGNAL					=	1;

#endif	// LM50SHARE_CONSTANTS
