// LM50Share_Ver.h

// This file contains descriptions of the history of changes to 
// the CLM50Share class.

// All revision numbers here will begin with S (for Share)

// Pat Summers
// American LaserWare, Inc.
// 09 AUG 2000

#ifndef LM50SHARE_VER
#define LM50SHARE_VER

//// REV S000 - 20000809 - IN THE BEGINNING... ////
// P. Summers - ALI
/*
	History begins here.
	
	Based on the LM45 Manager program.
	Modified to account for new/removed/changed hardware settings,
	i.e. Lamp -> LD; Water Conductivity removed; Water Flow added

	Any versions of the software prior to this cannot be supported.
*/
const UINT LM50SHARE_VER_000	=	199905060;
//// REV S000 /////////////////////////////////////

//// REV S001 - 20020408 - POWER RAMPING ////
//// REV S001 ///////////////////////////////
// P. Summers - ALI
/*
	From Laser Marker Software Specification 26 MAR 2002, Item #2:
	Power will be ramped from state to state rather than step
	changes to increase diode life.  A dialog is displayed during
	the ramping delay.

	The share data structure must store the previous PS LD Current
	setting to implement ramping to next setting.  For accuracy,
	this will be done as the port WORD value rather than the 
	floating point value already used, m_fPSLDCurrent.  Because the
	port may be used to set other parameters, such as freq, a seperate
	value must be saved for PS LD current only.

    Files affected:
		LM50Time.cpp

*/
//// REV S001 ///////////////////////////////
const UINT LM50SHARE_VER_001		=	20020408;

//// REV S002 - 20020409 - SIMMER CURRENT ////
// P. Summers - ALI
/*
	From Laser Marker Software Specification 26 MAR 2002, Item #3:
	Change LD current level to simmer level after long periods of
	inactivity.

    Files affected:
		LM50Time.cpp

*/
//// REV S002 ////////////////////////////////
const UINT LM50SHARE_VER_002		=	20020409;

//// REV S003 - 20020409 - CALIBRRATION ////
// P. Summers - ALI
/*
	Adds calibration data to shared data.
*/
//// REV S003 ////////////////////////////////
const UINT LM50SHARE_VER_003		=	20020616;

//// REV S004 - 20080318 - MT RACE UPDATE ////
//// REV S004 ////////////////////////////////
// P. Summers - ALI
/*
	Changes sharing logic to protect MMF from race conditions.
*/
//// REV S004 ////////////////////////////////
const UINT LM50SHARE_VER_004		=	20080318;

//// Define the latest version ////
//	const UINT LM50SHARE_VERSION	=	LM50SHARE_VER_000;
//	const UINT LM50SHARE_VERSION	=	LM50SHARE_VER_001;
//	const UINT LM50SHARE_VERSION	=	LM50SHARE_VER_002;
//	const UINT LM50SHARE_VERSION	=	LM50SHARE_VER_003;
const UINT LM50SHARE_VERSION		=	20080318;


//	#define LM50SHARE_VERSION_RELEASE_NUMBER		"01.00.00"
//	#define LM50SHARE_VERSION_RELEASE_DATE			"09 AUG 2000";
//	#define LM50SHARE_VERSION_RELEASE_NUMBER		"01.01.00"
//	#define LM50SHARE_VERSION_RELEASE_DATE			"08 APR 2002";
//	#define LM50SHARE_VERSION_RELEASE_NUMBER		"01.02.00"
//	#define LM50SHARE_VERSION_RELEASE_DATE			"09 APR 2002";
//	#define LM50SHARE_VERSION_RELEASE_NUMBER		"01.03.00"
//	#define LM50SHARE_VERSION_RELEASE_DATE			"16 JUN 2002";
#define LM50SHARE_VERSION_RELEASE_NUMBER		_T("01.04.00")
#define LM50SHARE_VERSION_RELEASE_DATE			_T("18 MAR 2008")

#endif LM50SHARE_VER
