// Header file for the CLens class
//
// Lens.h

// This class is the data structure for holding data concerning the
// various types of lenses for Synrad heads only!

#ifndef CLENS
#define CLENS

#include <afx.h>

#define LENS_1999_12_06			0
#define VER_LENS				LENS_1999_12_06


const int	LENS_NUMTYPES			=	9;

const int	LENS_TYPE_NONE			=	0;
#define		LENS_NAME_NONE				_T("Uncorrected")
const float	LENS_FOCAL_NONE			=	(float)-1;
const float	LENS_OPTX_NONE			=	(float)-1;
const float	LENS_OPTY_NONE			=	(float)-1;
const float	LENS_TOTX_NONE			=	(float)-1;
const float	LENS_TOTY_NONE			=	(float)-1;
const int	LENS_FENIXCODE_NONE		=	-1;

const int	LENS_TYPE_SHDH69		=	1;
#define		LENS_NAME_SHDH69			_T("SH/DH 69 mm")
const float	LENS_FOCAL_SHDH69		=	(float)69;
const float	LENS_OPTX_SHDH69		=	(float)38;
const float	LENS_OPTY_SHDH69		=	(float)38;
const float	LENS_TOTX_SHDH69		=	(float)38;
const float	LENS_TOTY_SHDH69		=	(float)38;
const int	LENS_FENIXCODE_SHDH69	=	-1;

const int	LENS_TYPE_SHDH125		=	2;
#define		LENS_NAME_SHDH125			_T("SH/DH 125 mm")
const float	LENS_FOCAL_SHDH125		=	(float)125;
const float	LENS_OPTX_SHDH125		=	(float)70;
const float	LENS_OPTY_SHDH125		=	(float)70;
const float	LENS_TOTX_SHDH125		=	(float)70;
const float	LENS_TOTY_SHDH125		=	(float)70;
const int	LENS_FENIXCODE_SHDH125	=	-1;

const int	LENS_TYPE_SHDH200		=	3;
#define		LENS_NAME_SHDH200			_T("SH/DH 200 mm")
const float	LENS_FOCAL_SHDH200		=	(float)200;
const float	LENS_OPTX_SHDH200		=	(float)110;
const float	LENS_OPTY_SHDH200		=	(float)110;
const float	LENS_TOTX_SHDH200		=	(float)110;
const float	LENS_TOTY_SHDH200		=	(float)110;
const int	LENS_FENIXCODE_SHDH200	=	-1;

const int	LENS_TYPE_SHDH370		=	4;
#define		LENS_NAME_SHDH370			_T("SH/DH 370 mm")
const float	LENS_FOCAL_SHDH370		=	(float)370;
const float	LENS_OPTX_SHDH370		=	(float)200;
const float	LENS_OPTY_SHDH370		=	(float)200;
const float	LENS_TOTX_SHDH370		=	(float)200;
const float	LENS_TOTY_SHDH370		=	(float)200;
const int	LENS_FENIXCODE_SHDH370	=	-1;

const int	LENS_TYPE_FENIX80		=	5;
#define		LENS_NAME_FENIX80			_T("Fenix 80 mm")
const float	LENS_FOCAL_FENIX80		=	(float)80;
const float	LENS_OPTX_FENIX80		=	(float)27;
const float	LENS_OPTY_FENIX80		=	(float)27;
const float	LENS_TOTX_FENIX80		=	(float)33.5;
const float	LENS_TOTY_FENIX80		=	(float)41.25;
const int	LENS_FENIXCODE_FENIX80	=	6;

const int	LENS_TYPE_FENIX125		=	6;
#define		LENS_NAME_FENIX125			_T("Fenix 125 mm")
const float	LENS_FOCAL_FENIX125		=	(float)125;
const float	LENS_OPTX_FENIX125		=	(float)74;
const float	LENS_OPTY_FENIX125		=	(float)74;
const float	LENS_TOTX_FENIX125		=	(float)85.7;
const float	LENS_TOTY_FENIX125		=	(float)105.6;
const int	LENS_FENIXCODE_FENIX125	=	5;

const int	LENS_TYPE_FENIX200		=	7;
#define		LENS_NAME_FENIX200			_T("Fenix 200 mm")
const float	LENS_FOCAL_FENIX200		=	(float)200;
const float	LENS_OPTX_FENIX200		=	(float)110;
const float	LENS_OPTY_FENIX200		=	(float)110;
const float	LENS_TOTX_FENIX200		=	(float)134;
const float	LENS_TOTY_FENIX200		=	(float)165;
const int	LENS_FENIXCODE_FENIX200	=	2;

const int	LENS_TYPE_FENIX370		=	8;
#define		LENS_NAME_FENIX370			_T("Fenix 370 mm")
const float	LENS_FOCAL_FENIX370		=	(float)370;
const float	LENS_OPTX_FENIX370		=	(float)198;
const float	LENS_OPTY_FENIX370		=	(float)198;
const float	LENS_TOTX_FENIX370		=	(float)241;
const float	LENS_TOTY_FENIX370		=	(float)297;
const int	LENS_FENIXCODE_FENIX370	=	4;



class CLens : public CObject
{

	DECLARE_SERIAL( CLens )

// Attributes
public:
	// Version info
	UINT
		m_nVersion;

	int
		m_iType;
	CString
		m_sName;
	float
		m_fFocalLength,
		m_fOptFieldX, m_fOptFieldY,
		m_fTotalFieldX, m_fTotalFieldY;
	int
		m_iFenixCode;

// Implementations
public:
	CLens(void);
	~CLens(void);

	void Init(void);

    void Serialize( CArchive& ar );

	BOOL IsCorrected(void);
	float GetXScaling(void);
	float GetYScaling(void);
	float GetFieldSize(void);

// Operators
	void operator =( const CLens& src );
	BOOL operator ==( const CLens& src );
public:
};

#endif // CLENS

