// TempGroup.h: interface for the CTempGroup class.
//
//////////////////////////////////////////////////////////////////////
/// 1.0362 DAN 3/24/01 GROUP SELECTION AND MANIPULATION ///

#if !defined(AFX_TEMPGROUP_H__56A74E20_2E89_11D5_AEE9_00609789DD58__INCLUDED_)
#define AFX_TEMPGROUP_H__56A74E20_2E89_11D5_AEE9_00609789DD58__INCLUDED_

#if _MSC_VER > 1000
#pragma once
#endif // _MSC_VER > 1000

//// 1.0527 PAT 16.04.01 TEMPGROUP ADDITIONS ////
const int TEMPGROUP_STRETCH_NONE			=	0;
const int TEMPGROUP_STRETCH_BOTH			=	1;
const int TEMPGROUP_STRETCH_HEIGHT			=	2;
const int TEMPGROUP_STRETCH_LENGTH			=	3;
//// 1.0527 /////////////////////////////////////

const int TEMPGROUP_ALIGN_LEFT		=	0;
const int TEMPGROUP_ALIGN_CENTER	=	1;
const int TEMPGROUP_ALIGN_RIGHT		=	2;
const int TEMPGROUP_ALIGN_TOP		=	3;
const int TEMPGROUP_ALIGN_MIDDLE	=	4;
const int TEMPGROUP_ALIGN_BOTTOM	=	5;

#include "Item.h"

class CGroupItem
{
// Attributes
public:
protected:
	// Pointer to the item
	CItem *m_pItem;

	// Item's relative position and orientation
	long	m_lDeltaX,
			m_lDeltaY,
			m_lDeltaRot;

	// Item's base height, length, and angle
	long	m_lBaseHeight,
			m_lBaseLength;
	long	m_lBaseRot;
	
	//// 1.0837 PAT 08.03.04 GROUP UNDO FIX ////
	int
		m_iLayerIndex,
		m_iItemIndex;
	//// 1.0837 ////////////////////////////////

// Operators
public:
	CGroupItem();
	~CGroupItem();
	
	void SetItem(CItem *pItem);

	//// 1.0837 PAT 08.03.04 GROUP UNDO FIX ////
	void SetItemIndex(int iLayer, int iItem);
	//// 1.0837 ////////////////////////////////
	
	/// 1.0366 DAN 5/20/01 GROUP ANGLE STRETCH FIX ///
	void CalculateRelative(long lX, long lY, long lAngle = 0);
	////1.0366////////////////////////////////////////
//// 1.0527 PAT 16.04.01 TEMPGROUP ADDITIONS ////
//	void Modify (long lX, long lY, long double ldXComp, long double ldYComp);
	void Modify (long lX, long lY, long double ldXComp, long double ldYComp, long double ldAng, int iMode = TEMPGROUP_STRETCH_NONE);
//// 1.0527 /////////////////////////////////////
	CItem *GetItem(void);

	//// 1.0665 PAT 24.04.02 GROUP UNDO FIX ////
	void operator = ( const CGroupItem& );
	BOOL operator == ( const CGroupItem& );
	//// 1.0665 ////////////////////////////////

	//// 1.0837 PAT 08.03.04 GROUP UNDO FIX ////
	int GetLayerIndex(void);
	int GetItemIndex(void);
	//// 1.0837 ////////////////////////////////

protected:

};


class CTempGroup  
{
// Attributes
public:
protected:
	// Position / Size parameters
	long	m_lXPos,
			m_lYPos,
			m_lLength,
			m_lHeight;

	// Scaling factors
	long double	m_ldXComp,
				m_ldYComp;

	// Rotation
	long	m_lRotAng;

	// Array of items in group
	CObArray	m_aItemData;

	// Flag to see if new item list has changed
	BOOL	m_bItemAddRemove;

	// Bounding box for the group
	CBBox	m_BBox;

	/// 1.0366 DAN 5/20/01 GROUP ANGLE STRETCH FIX ///
	BOOL	m_bEqualAngles;
	long	m_lAngle;
	////1.0366////////////////////////////////////////


// Operators
public:
	CTempGroup();
	virtual ~CTempGroup();
	void Init(void);
	void RemoveAll();

	//// 1.0837 PAT 08.03.04 GROUP UNDO FIX ////
	//	void AddItem(CItem *pItem);
	void AddItem(CItem *pItem, int iLayer, int iItem);
	//// 1.0837 ////////////////////////////////
	void RemoveItem(CItem *pItem);

	void UpdateValues();

	void MoveGroup(long lX, long lY);
	//// 1.0527 PAT 16.04.01 TEMPGROUP ADDITIONS ////
	//	void StretchGroup(long lLength, long lHeight);
	void StretchGroup(long lLength, long lHeight, int iMode);
	void RotateGroup(long lAngle);
	//// 1.0527 /////////////////////////////////////

	BOOL IsTempGroup(void);
	long GetSize(void);
	BOOL IsInGroup(CItem *pItem);

	CItem *GetLastItem(void);
	//// 1.0837 PAT 08.03.04 GROUP UNDO FIX ////
	CItem *GetLastItem(int *pLayer, int *pItem);
	//// 1.0837 ////////////////////////////////
	CItem *GetItem(long iItem);

	CBBox *GetBBox(void);
	void CalculateGroupBox(void);

	//// 1.0527 PAT 16.04.01 TEMPGROUP ADDITIONS ////
	long GetXPos(void);
	long GetYPos(void);
	long GetLength(void);
	long GetHeight(void);
	long double GetXComp(void);
	long double GetYComp(void);
	long GetRotAng(void);
	//// 1.0527 /////////////////////////////////////

	/// 1.0366 DAN 5/20/01 GROUP ANGLE STRETCH FIX ///
	BOOL EqualAngles(void);
	void SetOutOfAspectStretch(void);
	////1.0366////////////////////////////////////////

	//// 1.0665 PAT 24.04.02 GROUP UNDO FIX ////
	void operator = ( const CTempGroup& src);
	BOOL operator == ( const CTempGroup& src );
	//// 1.0665 ////////////////////////////////

	//// 1.0837 PAT 08.03.04 GROUP UNDO FIX ////
	BOOL IsInGroup(int iLayer, int iItem);

	int GetGroupSize(void);
	CGroupItem *GetGroupItem(int iIndex);
	//// 1.0837 ////////////////////////////////

	void Align(int AlignType);





};

#endif // !defined(AFX_TEMPGROUP_H__56A74E20_2E89_11D5_AEE9_00609789DD58__INCLUDED_)
