// Header file for CBarCode class
//
// American LaserWare, Inc
// Pat Summers
// 25 FEB 1998
//
//	Serves to hold the infromation required to create
//	a bar code typeface for a given set of text.  This
//	includes various bar code fill parameters like beam
//	width and beam spacing as well as the bar-space trans-
//	lation of the text for the BCALI font.
///////////////////////////////////////////////////////////

// barcode.h

#ifndef CBARCODE
#define CBARCODE

// Include standard headers
#ifndef _DLL
	#include <afx.h>
	#include <afxwin.h>
#endif

// Include version info
#ifdef _ALIUSE
	#include "..\Versions\versions.h"
#else
	#include "versions.h"
#endif

// Include header files required for members
//#include "..\WinScribe.h"

// CBarCode specific constant definitions
#define BC_MAX_BUF							80

#define BC_TYPE_DEFAULT						6
#define BC_NAME_DEFAULT						_T("Code 39")

#define BC_FONTNAME_BARCODES				_T("BCALI.ALF")
#define BC_STYLE							0
#define BC_SCALE							1
#define BC_SIZES_MAX						10

#define BC_ALI_CODE128						1000
#define BC_CODE128_NAME						_T("Code 128 Optimized")
#define BC_CODE128_A						0
#define BC_CODE128_B						1
#define BC_CODE128_C						2
#define BC_CODE128_JUMPA					229
#define BC_CODE128_JUMPB					228
#define BC_CODE128_JUMPC					227
#define BC_CODE128_SHIFTA					226
#define BC_CODE128_SHIFTB					226

#define BC_BASE_HEIGHT						1000
#define BC_BASE_WIDTH						1000

#define BC_OFFSET_BADDATA					32
#define BC_OFFSET_LEFTQZ					33
#define BC_OFFSET_RIGHTQZ					34
#define BC_OFFSET_MIDDLEQZ					35
#define BC_OFFSET_ICS						36
#define BC_OFFSET_SPACE						65
#define BC_OFFSET_BAR						97
#define BC_OFFSET_SHORTBAR					117

#define BC_ICS_FALSESIZE					21
#define BC_QZM_FALSESIZE					22

#define BC_BARTYPE_ERROR					0
#define BC_BARTYPE_BADDATA					1
#define BC_BARTYPE_SPACE					2
#define BC_BARTYPE_BAR						3
#define BC_BARTYPE_LEFTQZ					4
#define BC_BARTYPE_RIGHTQZ					5
#define BC_BARTYPE_MIDDLEQZ					6
#define BC_BARTYPE_ICS						7
#define BC_BARTYPE_SHORTBAR					8

#define BC_FILLSIZE_ERROR					0
#define BC_FILLSIZE_BADDATA					22
#define BC_FILLSIZE_SPACE					7
#define BC_FILLSIZE_SINGLE					10
#define BC_FILLSIZE_NORMAL(X)		((6*X) + 4)

#define BC_MOVE								1
#define BC_LINE								2
//// 1.0675 PAT 20.05.02 DATA MATRIX FILL ////
#define BC_ARC								3
//// 1.0675 //////////////////////////////////
#define BC_STOP								255

#define BC_ERR_MSG		_T("The current text is NOT valid for the current bar code format.\nPlease try a different bar code or data.\n\nNote that some bar codes have limited character sets, fixed data size, or both.")
//// 1.0299 PAT 17.03.00 BARCODE ICS/MQZ FIX ////
#define BC_WARNING_MSG	_T("The current variable text object has a bar code font.\nEnsure that the text always satisfies the bar code format.")
//// 1.0299 /////////////////////////////////////

#define BC_2D_OFFSET_BADDATA				32
#define BC_2D_OFFSET_OFF					65
#define BC_2D_OFFSET_ON						97

#define BC_2D_BARTYPE_ERROR					0
#define BC_2D_BARTYPE_BADDATA				1
#define BC_2D_BARTYPE_ON					2
#define BC_2D_BARTYPE_OFF					3
#define BC_2D_BARTYPE_QZTOP					4
#define BC_2D_BARCODE_QZLEFT				5
#define BC_2D_BARCODE_QZRIGHT				6
#define BC_2D_BARCODE_QZBOTTOM				7

#define BC_2D_FILLSIZE_ERROR				0
#define BC_2D_FILLSIZE_BADDATA				22
#define BC_2D_FILLSIZE_OFF					7
#define BC_2D_FILLSIZE_SINGLE				10
#define BC_2D_FILLSIZE_ON(X)				((6*X) + 4)
//// 1.0675 PAT 20.05.02 DATA MATRIX FILL ////
#define BC_2D_FILLSIZE_SINGLE_CIRCLE		27
#define BC_2D_FILLSIZE_ON_CIRCLE(X)			((23*X) + 4)
//// 1.0675 //////////////////////////////////
//// 1.1117 PAT 27.02.06 SPOTS IN 2DCODE ////
#define BC_2D_FILLSIZE_SPOTS				36
//// 1.1117 /////////////////////////////////

/*** ID MATRIX ***/
#define BC_ALI_IDMATRIX						2000
#define BC_FONTNAME_IDMATRIX				_T("IDMALI.ALF")
//// 1.0467 PAT 13.11.00 DATA MATRIX SIZE ////
//	#define BC_IDMATRIX_NAME					"ID Matrix"
#define BC_IDMATRIX_NAME					_T("Data Matrix")
//// 1.0467 //////////////////////////////////
#define BC_IDM_VALIDMATRIX					0
#define BC_IDM_MATRIXFILE					_T("MATRIX.IDM")
#define ID_MATRIX_IMPORTER					_T("idm")
#define ID_MATRIX_IMPORTER_EXE				_T("idm.exe")
/***/

#define BC_FORMAT_DEFTYPE					BCT_CODE128B

/*** 1.0036 DAN 9.6.98 GRAPHIC MEMORY REVISE ***/
// Hash values
#define BC_HASH_NAMESEP						'~'
#define BC_HASH_SEP							'^'

// Class type
#define BC_CLASS_NONE						0
#define BC_CLASS_NORMAL						1
#define BC_CLASS_2D							2
/***********************************************/

//// 1.0553 PAT 06.06.01 CUSTOM BARCODE ////
#define BC_ALI_GENCODE						3000
//// 1.0553 ////////////////////////////////

//// 1.1141 PAT 11.05.06 PDF417 ADDITION ////
#define BC_ALI_PDF417						2050
#define BC_FONTNAME_PDF417					_T("PDF-417")
#define BC_PDF417_NAME						_T("PDF 417")


//// 1.1141 /////////////////////////////////


//// 1.0675 PAT 20.05.02 DATA MATRIX FILL ////
#define BC_FILLTYPE_SNAKE					0
#define BC_FILLTYPE_CIRCLES					1
//// 1.0675 //////////////////////////////////
//// 1.0677 PAT 24.05.02 DATA MATRIX BITMAP ////
#define BC_FILLTYPE_RASTER					2
//// 1.0677 ////////////////////////////////////

//// 1.1117 PAT 27.02.06 SPOTS IN 2DCODE ////
#define BC_2D_DENSITYMODE_NORMAL			0
#define BC_2D_DENSITYMODE_1DOT				1
#define BC_2D_DENSITYMODE_SMALLEST			2


#define BC_2D_SPOTTYPE_PULSES				0
#define BC_2D_SPOTTYPE_DURATION				1
//// 1.1117 /////////////////////////////////

//// 1.1079 PAT 01.11.05 LINE SEPARATOR BARCODE PARAMETERS ////
#define BC_EOL_LS_NONE				0
#define BC_EOL_LS_LF				1
#define BC_EOL_LS_CR				2
#define BC_EOL_LS_CRLF				3
#define BC_EOL_LS_LFCR				4


#define BC_EOL_LAST_NONE			0
#define BC_EOL_LAST_SAME			1
//// 1.1079 ///////////////////////////////////////////////////

//// 1.1141 PAT 11.05.06 PDF417 ADDITION ////
#define BC_ECCMODE_LEVEL			0
#define BC_ECCMODE_PERCENT			1
//// 1.1141 /////////////////////////////////

//// 1.1149 PAT 24.05.06 PDF417 - TAKE 2 ////
#define BC_DEFAULT_ECCMODE_DM		BC_ECCMODE_LEVEL
#define BC_DEFAULT_ECC_LEVEL_DM		5
#define BC_DEFAULT_ECC_PCT_DM		0

#define BC_DEFAULT_ECCMODE_PDF417	BC_ECCMODE_PERCENT
#define BC_DEFAULT_ECC_LEVEL_PDF417	0
#define BC_DEFAULT_ECC_PCT_PDF417	10


// ECC LEVELS
//	DATA MATRIX
#define BC_ECC_LEVEL_DM_NUMBER				6

#define BC_ECC_LEVEL_DM_VALUE_000			0
#define BC_ECC_LEVEL_DM_VALUE_050			1
#define BC_ECC_LEVEL_DM_VALUE_080			2
#define BC_ECC_LEVEL_DM_VALUE_100			3
#define BC_ECC_LEVEL_DM_VALUE_140			4
#define BC_ECC_LEVEL_DM_VALUE_200			5

#define BC_ECC_LEVEL_DM_LABEL_000			_T("000")
#define BC_ECC_LEVEL_DM_LABEL_050			_T("050")
#define BC_ECC_LEVEL_DM_LABEL_080			_T("080")
#define BC_ECC_LEVEL_DM_LABEL_100			_T("100")
#define BC_ECC_LEVEL_DM_LABEL_140			_T("140")
#define BC_ECC_LEVEL_DM_LABEL_200			_T("200")

// PDF417
#define BC_ECC_LEVEL_PDF417_NUMBER			9

#define BC_ECC_LEVEL_PDF417_VALUE_0			0
#define BC_ECC_LEVEL_PDF417_VALUE_1			1
#define BC_ECC_LEVEL_PDF417_VALUE_2			2
#define BC_ECC_LEVEL_PDF417_VALUE_3			3
#define BC_ECC_LEVEL_PDF417_VALUE_4			4
#define BC_ECC_LEVEL_PDF417_VALUE_5			5
#define BC_ECC_LEVEL_PDF417_VALUE_6			6
#define BC_ECC_LEVEL_PDF417_VALUE_7			7
#define BC_ECC_LEVEL_PDF417_VALUE_8			8

#define BC_ECC_LEVEL_PDF417_LABEL_0			_T("0")
#define BC_ECC_LEVEL_PDF417_LABEL_1			_T("1")
#define BC_ECC_LEVEL_PDF417_LABEL_2			_T("2")
#define BC_ECC_LEVEL_PDF417_LABEL_3			_T("3")
#define BC_ECC_LEVEL_PDF417_LABEL_4			_T("4")
#define BC_ECC_LEVEL_PDF417_LABEL_5			_T("5")
#define BC_ECC_LEVEL_PDF417_LABEL_6			_T("6")
#define BC_ECC_LEVEL_PDF417_LABEL_7			_T("7")
#define BC_ECC_LEVEL_PDF417_LABEL_8			_T("8")

#define BC_ROWS_PDF417_LIMIT_VALUE_MAX			90
#define BC_COLS_PDF417_LIMIT_VALUE_MAX			30
#define BC_ROWS_PDF417_FIXED_VALUE_MAX			58
#define BC_COLS_PDF417_FIXED_VALUE_MAX			16

#define BC_RCLIMITS_PDF417_VALUE_LIMIT		0
#define BC_RCLIMITS_PDF417_VALUE_FIXED		1		
//// 1.1149 /////////////////////////////////


// Definitions for the bar code descriptions and samples 
#include "bcinfo.h"

//// 1.0467 PAT 13.11.00 DATA MATRIX SIZE ////
#include "BC_DataMatrix.h"
//// 1.0467 //////////////////////////////////
//// 1.0553 PAT 06.06.01 CUSTOM BARCODE ////
#include "GenCodeData.h"
//// 1.0553 ////////////////////////////////

class CBarCode : public CObject
{
	DECLARE_SERIAL (CBarCode)

//Attributes
public:
	int
		m_nVersion;
	CString
		m_sRoot,
		m_sTemp;
	int
		m_iType;
	BOOL
		m_bRev,
		m_bCheckSum,
		m_bUseCode128Opt,
		m_bBorder;
	CString
		m_sType,
		m_sBCText;
	long
		m_lBeamWidth,
		m_lBeamSpacing,
		m_lBarHeight,
		m_alBarWidth[BC_SIZES_MAX+1],
		m_alSpaceWidth[BC_SIZES_MAX+1],
		m_lLeftQZWidth,
		m_lRightQZWidth,
		m_lMiddleQZWidth,
		m_lICSpaceWidth,
		m_lBorderQZWidth;
	long
		m_lItemHeight,
		m_lItemLength;
	long double
		m_ldItemXComp;
	BOOL
		m_bValidFill,
		m_bUseOutline,
		m_bUseFill,
		m_bTooDense;
	CString
		m_sHashName;
	/*KLUDGE*/
	CObject
		*m_pDaVinci;
	CObArray
		m_BCFill;
	/*** ID MATRIX ***/
	BOOL
		m_bUse2D;
	CString
		m_s2DText;
	int
		m_i2DRows,
		m_i2DCols;
	CObArray
		m_2DFill;
	/***/
	
	/*** 1.0036 DAN 9.6.98 GRAPHIC MEMORY REVISE ***/
	int
		m_iClass;
	CString
		m_sLastFillName;
	/***********************************************/

	//// 1.0467 PAT 13.11.00 DATA MATRIX SIZE ////
	CDataMatrixSize
		m_DMSizes[BC_DM_SIZE_NUMBER];
	int
		m_iDMSize;
	//// 1.0467 //////////////////////////////////

	//// 1.0553 PAT 06.06.01 CUSTOM BARCODE ////
	CString
		m_sPrevText,
		m_sPrevBCText;
	CGenCodeData
		m_GCData,
		m_PrevGCData;
	//// 1.0553 ////////////////////////////////
	//// 1.1145 PAT 24.05.06 PDF417 - TAKE 2 ////
	int m_iPrevType;
	//// 1.1145 /////////////////////////////////

	//// 1.0675 PAT 20.05.02 DATA MATRIX FILL ////
	int
		m_iFillType;
	//// 1.0675 //////////////////////////////////

	//// 1.0685 PAT 08.07.02 ONE DOT PER CELL ////
	BOOL
		m_b2DOneDotPerCell;
	//// 1.0685 //////////////////////////////////

	//// 1.1019 PAT 31.05.05 DATA MATRIX BAD DATA SYMBOL ////
	BOOL
		m_bPrevValid;
	int
		m_iPrevDMSize;
	//// 1.1019 /////////////////////////////////////////////

	//// 1.1079 PAT 01.11.05 LINE SEPARATOR BARCODE PARAMETERS ////
	int m_iLineSeparator;
	int m_iEndOfLastLine;
	//// 1.1079 ///////////////////////////////////////////////////

	//// 1.1117 PAT 27.02.06 SPOTS IN 2DCODE ////
	BOOL m_b2DSmallestSize;
	int m_i2DSpotType;
	BOOL m_b2DSpotUseMatFile;
	double m_d2DSpotDuration;
	int m_i2DSpotPulses;
	double m_d2DSpotRepRate;
	//// 1.1117 /////////////////////////////////

	//// 1.1141 PAT 11.05.06 PDF417 ADDITION ////
	BOOL m_bTruncated;
	int m_iECCMode;
	int m_iECCLevel;
	int m_iECCPercent;
	int m_iMaxRows;
	int m_iMaxCols;
	//// 1.1141 /////////////////////////////////

	//// 1.1149 PAT 24.05.06 PDF417 - TAKE 2 ////
	int m_iRCLimits;

	BOOL m_bPrevTruncated;
	int m_iPrevECCMode;
	int m_iPrevECCLevel;
	int m_iPrevECCPercent;
	int m_iPrevMaxRows;
	int m_iPrevMaxCols;
	int m_iPrevRCLimits;

	CString m_sEncodeText;
	//// 1.1149 /////////////////////////////////

// Implementations
public:
	CBarCode();							// Constructor
	~CBarCode();						// Destructor
	void Init(void);					// Initializes members
	void Serialize(CArchive&);			// Load / Save routines
	void SetItemParameters(long, long); 
	/*** 1.0051 PAT 19.05.98 MULTIPLE LINES AND BARCODES ***/
	BOOL CheckData(CString);
	CString TextToCode(CString);		// Converts the given string
											// from text to bars
	CString ModifyText(CString, int, CString&);	// Changes string to have right
										// number of characters and checksums
	/*******************************************************/
	_TXCHAR GetCheckChar(CString, int);	// Gets the checksum of the string for
										// for the given bar code type
	int Code39Ord(_TXCHAR);				// Gets the ordinal in Codabar
	_TXCHAR Code39Chr(int);				// Gets the character for an ordinal
	int CodabarOrd(_TXCHAR);				// Gets the ordinal in Codabar
	_TXCHAR CodabarChr(int);				// Gets the character for an ordinal
	CString Code128Opt(CString);		// Optimizes a string for Code 128 A,B & C
	CString GetHashName(void);			// Creates the hash name
	BOOL FillChar(_TXCHAR, long *);		// Fills a character
	int GetFillSize(_TXCHAR);				// Returns the fill size
	int GetBarType(_TXCHAR);
	long GetBarWidth(int, _TXCHAR);
	/*KLUDGE*/
	void DeleteFills(void);
	void FillChar(long, long double, _TUCHAR);
	/***/
	/*** ID MATRIX ***/
	CString TextToCode2D(CString);
	CString GetIDMText(CString);
	//// 1.0467 PAT 13.11.00 DATA MATRIX SIZE ////
	CString GetDMText(CString sText);
	//// 1.0467 //////////////////////////////////
	BOOL CheckData2D(CString);
	BOOL FillChar2D(_TXCHAR, long *);
	int GetFillSize2D(_TXCHAR);
	int GetBarType2D(_TXCHAR);
	long GetBarWidth2D(int, _TXCHAR);
	void FillChar2D(long, long double, _TXCHAR);
	/***/
	long *GetFill(_TUCHAR);
	BOOL IsFilled(_TUCHAR);
	CString GetEncodedText(void);

	/*** 1.0036 DAN 9.6.98 GRAPHIC MEMORY REVISE ***/
	CString GetFillName(void);			// Creates the fill name for the bar code
	/***********************************************/
	
	//// 1.0545 PAT 22.05.01 BARCODE LISTFILE COMMAND ////
	BOOL IsSupportedName(CString sName, int *pType);
//// 1.1325 PAT 08.06.07 UNTYPED FIXES ////
//	Is2DCode(int iType);
	BOOL Is2DCode(int iType);
//// 1.1325 ///////////////////////////////
	//// 1.0545 //////////////////////////////////////////

	//// 1.0553 PAT 06.06.01 CUSTOM BARCODE ////
	CString GetGenCodeText(CString sText);
	//// 1.0553 ////////////////////////////////

	//// 1.0675 PAT 20.05.02 DATA MATRIX FILL ////
	BOOL FillChar2DSnake(long *pList);
	BOOL FillChar2DCircles(long *pList);
	int GetFillSize2DSnake(void);
	int GetFillSize2DCircles(void);
	//// 1.0675 //////////////////////////////////
	//// 1.1117 PAT 27.02.06 SPOTS IN 2DCODE ////
	BOOL FillChar2DSpots(long *pList);
	int GetFillSize2DSpots(void);
	//// 1.1117 /////////////////////////////////

	//// 1.0677 PAT 24.05.02 DATA MATRIX BITMAP ////
	HANDLE
		m_hImage2DCode;
	BOOL RenderAsRaster(void);
	void RenderRasterBarcode(void);
	//// 1.0677 ////////////////////////////////////

	//// 1.1079 PAT 01.11.05 LINE SEPARATOR BARCODE PARAMETERS ////
	CString GetLineSeparatorString(void);
	CString GetEndOfLastLineString(void);
	//// 1.1079 ///////////////////////////////////////////////////

	//// 1.1141 PAT 11.05.06 PDF417 ADDITION ////
	CString GetPDF417Text(CString sText);
	//// 1.1141 /////////////////////////////////
	
	//// 1.1149 PAT 24.05.06 PDF417 - TAKE 2 ////
	BOOL MustRegenerate2D(void);
	//// 1.1149 /////////////////////////////////

//Operators
public:
	// Equate =
	void operator =( const CBarCode& src );
	// Equivalence ==
	BOOL operator ==( const CBarCode& src );

	//// JT080116A Adding row/column for PDF417 ////
	unsigned short
		m_nPDFRows,
		m_nPDFCols;
	//// JT080116A /////////////////////////////////
};

#endif

