// Header file for the CCalData class
//
// caldata.h

// This class will store the data used by the CCalibrate class
// to implement a calibration routine

#ifndef CCALDATA
#define CCALDATA

/*** 1.0084 12.22.98 MOVE CFG TO WSDATA PRJ ***/
#include <afx.h>
#include <afxdlgs.h>
/****1.0084************************************/

#ifdef _ALIUSE
// Include version info
	#include "..\Versions\versions.h"
#else
	#include "versions.h"
#endif

#define CAL_POINTS				10
#define CAL_PRECISION			1000

#define	CAL_DAC_DEFAULT			0
#define	CAL_DAC_12BIT			1
#define	CAL_DAC_16BIT			2

#define	CAL_NUMDACS				3
#define	CAL_DACMAX_DEFAULT		0x0FFF
#define	CAL_DACMAX_12BIT		0x0FFF
#define	CAL_DACMAX_16BIT		0xFFFF

#define	CAL_ERR_OUTOFBOUNDS		-1
/*** 1.0039 PAT 14.05.98 CALDATA INIT VALUES ***/
#define CAL_ERR_NONE			0
#define CAL_ERR_LOAD			-1
#define CAL_ERR_SAVE			-2
/***********************************************/

/*** 1.0081 PAT 16.06.98 CALDATA TYPES ***/
#define CAL_TYPE_NONE			0
#define CAL_TYPE_POWER			1
#define CAL_TYPE_FREQ			2
#define CAL_TYPE_FOCUS			3
/*****************************************/

class CCalData : public CObject
{

	DECLARE_SERIAL(CCalData)
		
// Attributes
public:
	// Version info
	UINT
		m_nVersion;
	
	UINT
		m_nDACType;
	long
		m_lDomain[CAL_POINTS+1],
		m_lRange[CAL_POINTS+1];
	CString
		m_sDispDomainLabel,
		m_sDispDomainUnits,
		m_sDispRangeLabel,
		m_sDispRangeUnits,
		m_sNotice,
		m_sWarning,
		m_sDomainPrompt,
		m_sRangePrompt;
	BOOL
		m_bValidFile;
	CString
		m_sName;
	CTime
		m_tTimeStamp;
	UINT
		m_nType;
	
	//// 1.0893 PAT 14.06.04 CAL MAX VOLT LIMIT ////
	BOOL
		m_bLimitEnabled;
	//// 1.0893 ////////////////////////////////////

protected:
	UINT
		m_nDACSize[CAL_NUMDACS];

// Implementations
public:
	CCalData(void);
	~CCalData(void);

	void	Init(void);
	void	InitLists(double, double);
	long	GetDACType(UINT);

	long	GetDACof(long);
	long	GetDomainFor(long);
	long	GetDomainFor(double);
	long	Interpolate(long, long [], long []);
	int		Advance(long, long []);
	long	GetDACSize(void);

	double	GetDispDomainValue(UINT);
	double	GetDispRangeValue(UINT);
	void	SetDomainValue(UINT, CString);
	void	SetRangeValue(UINT, double);

	int		Load(CString);
	int		Save(CString);
	void	Serialize(CArchive&);

	CString MakeRelative(CString sPath);
	CString MakeAbsolute(CString sPath);


// Operators
public:
	//// 1.0267 PAT 28.12.99 CONFIG = & == OPERATORS ////
	void operator = (const CCalData& src);
	BOOL operator == (const CCalData& src);
	//// 1.0267 /////////////////////////////////////////

	//// 1.0713 PAT 11.10.02 GS8 POWER ////
	long GetDomainMax(void);
	long GetRangeMax(void);
	//// 1.0713 ///////////////////////////

	//// 1.0893 PAT 14.06.04 CAL MAX VOLT LIMIT ////
	BOOL GetLimitEnabled(void);
	void SetLimitEnabled(BOOL bEnable);
	double GetDispDomainLimit(void);
	double GetDispRangeLimit(void);
	CString GetDispDomainUnits(void);
	CString GetDispRangeUnits(void);
	//// 1.0893 ////////////////////////////////////

};

#endif	// CCALDATA

