// Header file for CDateCode class
//
// American LaserWare, Inc.
// Pat Summers
// 13 SEP 97
//
/****
	The CDateCode class is used to obtain a CString containing
	the date code specifed for variable text/date code items.
	It uses CTime to obtain the current date/time and contains
	functions to convert this value to the properly formatted
	text for each date format.
****/
//
/////////////////////////////////////////////////////////

// datecode.h

#ifndef CDATECODE
#define CDATECODE

// Include header files required for members

// Class specific constant definitions
#define DC_ITOA_BASE			10
#define	DC_MAX_STRING			80
#define DC_OFFSET				10000

#define DC_TYPE_DEFAULT			0
#define DC_TYPE_VICKERS			1
#define DC_TYPE_AMERICAN		2
#define DC_TYPE_EUROPEAN		3
#define DC_TYPE_EUROAMPM		4
#define DC_TYPE_WEEKYEAR		5
#define DC_TYPE_JULIAN			6
#define	DC_TYPE_MACSA			7
#define DC_TYPE_CHEM			8
#define DC_TYPE_LUCENT			9
#define DC_TYPE_AMP				10
#define DC_TYPE_NUGENT			11
#define DC_TYPE_YEARWEEK		12
#define DC_TYPE_QUARTERYEAR		13
//// 1.0515 PAT 29.03.01 JULIAN YEAR 3-2 DATECODE ////
#define DC_TYPE_JULIAN3YEAR2	14
//// 1.0515 //////////////////////////////////////////
//// 1.0555 PAT 10.06.01 MMYYYY DATECODE ////
#define DC_TYPE_MONTH2YEAR4		15
//// 1.0555 /////////////////////////////////
//// 1.0609 PAT 05.10.01 HH:MM DATE/TIME CODE ////
#define DC_TYPE_24HOUR_HHMM		16
//// 1.0609 //////////////////////////////////////
//// 1.0715 PAT 22.10.02 NEW JULIAN DATE CODE ////
#define DC_TYPE_JULIAN3			17
//// 1.0715 //////////////////////////////////////
//// 1.0809 PAT 02.12.03 DATE CODE MMMxDDxYYYY ////
#define DC_TYPE_MONDAY2YEAR4	18
//// 1.0809 ///////////////////////////////////////
//// 1.0815 PAT 09.12.03 DATE CODE DDxMMMxYYYY ////
#define DC_TYPE_DAY2MONYEAR4	19
//// 1.0815 ///////////////////////////////////////
//// 1.0915 PAT 01.08.04 SHIFT CODE HOURLY DATECODE ////
#define DC_TYPE_SHIFT_HOURLY	20
//// 1.0915 ////////////////////////////////////////////
//// 1.0983 PAT 27.01.05 MONTH(A)YEAR(2) DATE CODE ////
#define DC_TYPE_MONTHAYEAR2		21
//// 1.0983 ///////////////////////////////////////////
//// 1.1059 PAT 30.09.05 YEAR2 DATECODE ////
#define DC_TYPE_YEAR2			22
//// 1.1059 ////////////////////////////////
//// 1.1073 PAT 16.10.05 DATE CODES Y1,Y3,Y4 ////
#define DC_TYPE_YEAR1			23
#define DC_TYPE_YEAR3			24
#define DC_TYPE_YEAR4			25
//// 1.1073 /////////////////////////////////////
//// 1.1085 PAT 07.12.05 DAY3YEAR2HOUR2 ////
#define DC_TYPE_HOUR2			26
#define DC_TYPE_DAY3YEAR1HOUR2	27
//// 1.1085 ////////////////////////////////
//// 1.1125 PAT 07.04.06 DATE AND TIME CODE ////
#define DC_TYPE_12HOUR2			28
#define	DC_TYPE_MINUTE2			29
#define DC_TYPE_SECOND2			30
#define	DC_TYPE_AMERTIME		31
#define DC_TYPE_VISTEON			32
//// 1.1125 ////////////////////////////////////
//// 1.1147 PAT 24.05.06 NEW DATECODE ////
#define DC_TYPE_DAYOFMONTH		33
#define DC_TYPE_DAYOFMONTH2		34
#define DC_TYPE_MONTHJAN		35
#define DC_TYPE_MONTHENE		36
//// 1.1147 //////////////////////////////
//// 1.1165 PAT 13.07.06 MONTH OF YEAR DATECODES ////
#define DC_TYPE_MONTHOFYEAR		37
#define DC_TYPE_MONTHOFYEAR2	38
//// 1.1165 /////////////////////////////////////////
////080407A Two-letter month code ////
#define DC_TYPE_MONTH2LETTER	39
//// JT080407A ////
//// PS081016A NEW CUSTOM DATE CODE ////
#define DC_TYPE_DDMYHHMMCODE	40
//// PS081016A /////////////////////////
//// PS081208A NEW CUSTOM DATECODE ////
#define DC_TYPE_DDMYCODE		41
//// PS081208A ////////////////////////
//// PS090129A CALENDER WEEK OF YEAR DATECODE ////
#define DC_TYPE_CAL_WOY			42
#define DC_TYPE_CAL_WOY2		43
//// PS090129A ///////////////////////////////////
//// PS090804A MM-YYYY DATE CODE ////
#define DC_TYPE_MM_DASH_YYYY	44
//// PS090804A //////////////////////
//// PS20120430C DATE CODE YJJJS# ////
#define DC_TYPE_YJJJS			45
//// PS20120430C /////////////////////




//// 1.0241 PAT 12.10.99 DATE CODE FIXES ////
#define DC_TYPENAME_DEFAULT			_T("Default")
#define DC_TYPENAME_VICKERS			_T("Custom #1")
#define DC_TYPENAME_AMERICAN		_T("American")
#define DC_TYPENAME_EUROPEAN		_T("European")
#define DC_TYPENAME_EUROAMPM		_T("Euro - AM/PM")
#define DC_TYPENAME_WEEKYEAR		_T("Week Year AM/PM")
//// 1.0715 PAT 22.10.02 NEW JULIAN DATE CODE ////
//	#define DC_TYPENAME_JULIAN			"Julian"
#define DC_TYPENAME_JULIAN			_T("Julian(3) Year(1)")
//// 1.0715 //////////////////////////////////////
#define	DC_TYPENAME_MACSA			_T("Euro Time")
#define DC_TYPENAME_CHEM			_T("Custom #2")
#define DC_TYPENAME_LUCENT			_T("Custom #3")
#define DC_TYPENAME_AMP				_T("Custom #4")
#define DC_TYPENAME_NUGENT			_T("Week Year")
#define DC_TYPENAME_YEARWEEK		_T("Year Week")
#define DC_TYPENAME_QUARTERYEAR		_T("Quarter 'Q' Year")
//// 1.0241 /////////////////////////////////
//// 1.0515 PAT 29.03.01 JULIAN YEAR 3-2 DATECODE ////
#define DC_TYPENAME_JULIAN3YEAR2	_T("Julian(3) Year(2)")
//// 1.0515 //////////////////////////////////////////
//// 1.0555 PAT 10.06.01 MMYYYY DATECODE ////
#define DC_TYPENAME_MONTH2YEAR4		_T("Month(2) Year(4)")
//// 1.0555 /////////////////////////////////
//// 1.0609 PAT 05.10.01 HH:MM DATE/TIME CODE ////
#define DC_TYPENAME_24HOUR_HHMM		_T("24 Hour (HH:MM)")
//// 1.0609 //////////////////////////////////////
//// 1.0715 PAT 22.10.02 NEW JULIAN DATE CODE ////
#define DC_TYPENAME_JULIAN3			_T("Julian(3)")
//// 1.0715 //////////////////////////////////////
//// 1.0809 PAT 02.12.03 DATE CODE MMMxDDxYYYY ////
#define DC_TYPENAME_MONDAY2YEAR4	_T("MON Day(2) Year(4)")
//// 1.0809 ///////////////////////////////////////
//// 1.0815 PAT 09.12.03 DATE CODE DDxMMMxYYYY ////
#define DC_TYPENAME_DAY2MONYEAR4	_T("Day(2) MON Year(4)")
//// 1.0815 ///////////////////////////////////////
//// 1.0915 PAT 01.08.04 SHIFT CODE HOURLY DATECODE ////
#define DC_TYPENAME_SHIFT_HOURLY	_T("Custom #5")
//// 1.0915 ////////////////////////////////////////////
//// 1.0983 PAT 27.01.05 MONTH(A)YEAR(2) DATE CODE ////
#define DC_TYPENAME_MONTHAYEAR2		_T("Month(A) Year(2)")
//// 1.0983 ///////////////////////////////////////////
//// 1.1059 PAT 30.09.05 YEAR2 DATECODE ////
#define DC_TYPENAME_YEAR2			_T("Year(2)")
//// 1.1059 ////////////////////////////////
//// 1.1073 PAT 16.10.05 DATE CODES Y1,Y3,Y4 ////
#define DC_TYPENAME_YEAR1			_T("Year(1)")
#define DC_TYPENAME_YEAR3			_T("Year(3)")
#define DC_TYPENAME_YEAR4			_T("Year(4)")
//// 1.1073 /////////////////////////////////////
//// 1.1085 PAT 07.12.05 DAY3YEAR2HOUR2 ////
#define DC_TYPENAME_HOUR2			_T("Hour(2)")
#define DC_TYPENAME_DAY3YEAR1HOUR2	_T("Day(3)Year(1)Hour(2)")
//// 1.1085 ////////////////////////////////
//// 1.1125 PAT 07.04.06 DATE AND TIME CODE ////
#define DC_TYPENAME_12HOUR2			_T("12 Hour (2)")
#define DC_TYPENAME_MINUTE2			_T("Minute (2)")
#define DC_TYPENAME_SECOND2			_T("Second (2)")
#define DC_TYPENAME_AMERTIME		_T("Amer. Time")
#define DC_TYPENAME_VISTEON			_T("VIST")
//// 1.1125 ////////////////////////////////////
//// 1.1147 PAT 24.05.06 NEW DATECODE ////
#define DC_TYPENAME_DAYOFMONTH		_T("Day of Month")
#define DC_TYPENAME_DAYOFMONTH2		_T("Day of Month(2)")
#define DC_TYPENAME_MONTHJAN		_T("Month(JAN)")
#define DC_TYPENAME_MONTHENE		_T("Month(ENE) - Spanish")
//// 1.1147 //////////////////////////////
//// 1.1165 PAT 13.07.06 MONTH OF YEAR DATECODES ////
#define DC_TYPENAME_MONTHOFYEAR		_T("Month")
#define DC_TYPENAME_MONTHOFYEAR2	_T("Month(2)")
//// 1.1165 /////////////////////////////////////////
//// JT080407A Two-letter month code ////
#define DC_TYPENAME_MONTH2LETTER	_T("Month(JA)")
//// JT080407A ////
//// PS081016A NEW CUSTOM DATE CODE ////
#define DC_TYPENAME_DDMYHHMMCODE	_T("Custom #6")
//// PS081016A /////////////////////////
//// PS081208A NEW CUSTOM DATECODE ////
#define DC_TYPENAME_DDMYCODE		_T("Custom #7")
//// PS081208A ////////////////////////
//// PS090129A CALENDER WEEK OF YEAR DATECODE ////
#define DC_TYPENAME_CAL_WOY			_T("Cal. Week of Year")
#define DC_TYPENAME_CAL_WOY2		_T("Cal. Week of Year(2)")
//// PS090129A ///////////////////////////////////
//// PS090804A MM-YYYY DATE CODE ////
#define DC_TYPENAME_MM_DASH_YYYY	_T("MM-YYYY")
//// PS090804A //////////////////////
//// PS20120430C DATE CODE YJJJS# ////
//	#define DC_TYPENAME_YJJJS			_T("YJJJShift")
#define DC_TYPENAME_YJJJS			_T("Custom #8")
//// PS20120430C /////////////////////

// Date code class definition
class CDateCode
{
public:
//Attributes
	UINT
		m_nCode;
	CTime
		m_Clock;
	int	
		m_nYear,
		m_nMonth,
		m_nWeekOfYear,
		m_nDayOfYear,
		m_nDayOfMonth,
		m_nDayOfWeek,	
		m_nHour,
		m_nMinute,
		m_nSecond,
		m_bLeapYear,
		m_anDaysPerMonth[13];

	//// PS090129A CALENDER WEEK OF YEAR DATECODE ////
	int	m_nDayOfWeekJan1;
	int m_nWeekOfYearCal;
	//// PS090129A ///////////////////////////////////

#ifndef _PROLASEDLL
//	_TXCHAR
	char
#else
	char
#endif // _PROLASEDLL
		m_cMonthLetter,
		m_cString[DC_MAX_STRING];
	CString
		m_sString,
		m_sText;
	//// 1.0809 PAT 02.12.03 DATE CODE MMMxDDxYYYY ////
	CString
		m_sMonth3LetterCaps;
	//// 1.0809 ///////////////////////////////////////

	//// 1.0915 PAT 01.08.04 SHIFT CODE HOURLY DATECODE ////
	CString
		m_sMahleShiftCode;
	CString
		m_sHourly4;
	//// 1.0915 ////////////////////////////////////////////

	//// 1.1147 PAT 24.05.06 NEW DATECODE ////
	CString m_sMonth3LetterCapsSpanish;
	//// 1.1147 //////////////////////////////
	
	//// PS20100316B ISO8601 WEEK OF YEAR ////
	int m_nISO8601_WeekYear;
	int m_nISO8601_Week;
	int m_nISO8601_DayOfWeek;

	BOOL m_bISO8601_Week_Enabled;
	//// PS20100316B /////////////////////////


public:
//Implimentations
	CDateCode(void);
	~CDateCode(void);
	void SetClock(void);
	//// PS20100316B ISO8601 WEEK OF YEAR ////
	void SetClock(CTime tClock);
	//// PS20100316B /////////////////////////

	CString GetDateCode(int);
	CString GetVickers(void);
	CString GetAmerican(void);
	CString GetEuropean(void);
	CString GetEuroAmPm(void);
	CString GetWeekYear(void);
	//// 1.0715 PAT 22.10.02 NEW JULIAN DATE CODE ////
	//	CString GetJulian(void);
	CString GetJulian3Year1(void);
	//// 1.0715 //////////////////////////////////////
	CString GetMacsa(void);
	CString GetChem(void);
	CString GetLucent(void);
	CString GetAmp(void);
	CString GetNugent(void);
	CString GetYearWeek(void);
	CString GetQuarterYear(void);
	//// 1.0515 PAT 29.03.01 JULIAN YEAR 3-2 DATECODE ////
	CString GetJulian3Year2(void);
	//// 1.0515 //////////////////////////////////////////
	//// 1.0555 PAT 10.06.01 MMYYYY DATECODE ////
	CString GetMonth2Year4(void);
	//// 1.0555 /////////////////////////////////
	//// 1.0609 PAT 05.10.01 HH:MM DATE/TIME CODE ////
	CString Get24HourHHMM(void);
	//// 1.0609 //////////////////////////////////////
	//// 1.0715 PAT 22.10.02 NEW JULIAN DATE CODE ////
	CString GetJulian3(void);
	//// 1.0715 //////////////////////////////////////
	//// 1.0809 PAT 02.12.03 DATE CODE MMMxDDxYYYY ////
	CString GetMONDay2Year4(void);
	//// 1.0809 ///////////////////////////////////////
	//// 1.0815 PAT 09.12.03 DATE CODE DDxMMMxYYYY ////
	CString GetDay2MONYear4(void);
	//// 1.0815 ///////////////////////////////////////
	//// 1.0915 PAT 01.08.04 HOURLY+SHIFT DATECODE ////
	CString GetShiftHourly(void);
	//// 1.0915 ///////////////////////////////////////
	//// 1.0983 PAT 27.01.05 MONTH(A)YEAR(2) DATE CODE ////
	CString GetMonthAYear2(void);
	//// 1.0983 ///////////////////////////////////////////
	//// 1.1059 PAT 30.09.05 YEAR2 DATECODE ////
	CString GetYear2(void);
	//// 1.1059 ////////////////////////////////
	//// 1.1073 PAT 16.10.05 DATE CODES Y1,Y3,Y4 ////
	CString GetYear1(void);
	CString GetYear3(void);
	CString GetYear4(void);
	//// 1.1073 /////////////////////////////////////
	//// 1.1085 PAT 07.12.05 DAY3YEAR2HOUR2 ////
	CString GetHour2(void);
	CString GetDay3Year1Hour2(void);
	//// 1.1085 ////////////////////////////////

	//// 1.1125 PAT 07.04.06 DATE AND TIME CODE ////
	CString Get12Hour2(void);
	CString GetMinute2(void);
	CString GetSecond2(void);
	CString GetAmerTime(void);
	CString GetVisteon(void);
	//// 1.1125 ////////////////////////////////////

	//// 1.1147 PAT 24.05.06 NEW DATECODE ////
	CString GetDayOfMonth(void);
	CString GetDayOfMonth2(void);
	CString GetMonthJAN(void);
	CString GetMonthENE(void);
	//// 1.1147 //////////////////////////////

	//// 1.1165 PAT 13.07.06 MONTH OF YEAR DATECODES ////
	CString GetMonthOfYear(void);
	CString GetMonthOfYear2(void);
	//// 1.1165 /////////////////////////////////////////

	//// JT080407A Two-letter month code ////
	CString GetMonth2LetterCaps(void);
	//// JT080407A ////

	//// PS081016A NEW CUSTOM DATE CODE ////
	CString GetDDMYHHMMCODE(void);
	//// PS081016A /////////////////////////
	
	//// PS081208A NEW CUSTOM DATECODE ////
	CString GetDDMYCODE(void);
	//// PS081208A ////////////////////////

	//// PS090129A CALENDER WEEK OF YEAR DATECODE ////
	CString GetCalWOY(void);
	CString GetCalWOY2(void);
	//// PS090129A ///////////////////////////////////

	//// PS090804A MM-YYYY DATE CODE ////
	CString GetMMdashYYYY(void);
	//// PS090804A //////////////////////

	//// PS20120430C DATE CODE YJJJS# ////
	CString GetYJJJShift(void);
	//// PS20120430C /////////////////////

protected:
	//Implementations
	void SetLeapYear(void);
	void SetDaysPerMonth(void);
	void GetDayOfYear(void);
	void GetWeekOfYear(void);
	void GetMonthLetter(void);
	//// 1.0809 PAT 02.12.03 DATE CODE MMMxDDxYYYY ////
	void GetMonth3LetterCaps(void);
	//// 1.0809 ///////////////////////////////////////
	//// 1.0915 PAT 01.08.04 SHIFT CODE HOURLY DATECODE ////
	void GetMahleShiftCode(void);
	void GetHourly4(void);
	//// 1.0915 ////////////////////////////////////////////
	//// 1.1147 PAT 24.05.06 NEW DATECODE ////
	void GetMonth3LetterCapsSpanish(void);
	//// 1.1147 //////////////////////////////

	//// PS090129A CALENDER WEEK OF YEAR DATECODE ////
	void GetDayOfWeekOfJan1(void);
	void GetWeekOfYearCal(void);
	//// PS090129A ///////////////////////////////////

	//// PS20100316B ISO8601 WEEK OF YEAR ////
	void SetISO8601Values(void);
	BOOL IsLeapYear(int iYear);
	int GetDayOfYear(int iYear, int iMonthOfYear, int iDayOfMonth);
	//// PS20100316B /////////////////////////
};

#endif
