// Header file for ClGHeader class
//
// American LaserWare, Inc
// Pat Summers
// 19 AUG 1997
//
//	Serves to hold all the possible data required for the
//	header information of a symbol found in the CLongList.
//  Member function facilitate retrieving, loading, saving,
//	and modifying that data.
///////////////////////////////////////////////////////////

// lgheader.h

#ifndef CLGHEADER
#define CLGHEADER

// Include header files required for members
#include "vgconst.h"
#include "longlist.h"
#include "ldgvecto.h"

// ClGHeader specific constant definitions
#define GH_SIZE_DEF			VG_HS_NEWGRAPHIC // 102202
#define GH_TYPE_DEF			VG_HT_NEWGRAPHIC // 102202
#define GH_VALUE_DEF		0
#define GH_XTOTAL_DEF		1
#define GH_XCELL_DEF		1
#define GH_YTOTAL_DEF		10
#define GH_YCELL_DEF		10		

class ClGHeader : public CObject
{
	DECLARE_SERIAL (ClGHeader)

//Attributes
public:
	int
		m_iSize;
	long
		m_lType,
		m_lXTotal,
		m_lYTotal,
		m_lRealHeight,            // integer .0001" increments 102202
		m_lRealWidth,			  // integer .0001" increments 102202	
		m_lRealXPos,
		m_lRealYPos,
		m_lXCell,
		m_lYCell,
		m_lAscend,
		m_lDescend,
		m_lLKern,
		m_lRKern;

// Implementations
public:
	ClGHeader();						// Constructor
	~ClGHeader();						// Destructor
	void Init(void);					// Initializes members
	void Serialize(CArchive&);		// Load / Save routines
    int GetSize(void);					// Returns the header size (in longs)
	long GetXTotal(void);				// Returns the total x value
	long GetYTotal(void);				// Returns the total y value
	long GetRealHeight(void);			// Returns the Real world height in .0001" increments
	long GetRealWidth(void);			// Returns the Real world width in .0001" increments
	long GetRealXPos(void);				// Returns the Real world left most extent in 0.0001" units
	long GetRealYPos(void);				// Returns the Real world bottom most extent in 0.0001" units
	long GetXCell(void);				// Returns the cell x value
	long GetYCell(void);				// Returns the cell y value
	long GetAscend(void);				// Returns the ascender value
	long GetDescend(void);				// Returns the descender value
	long GetLKern(void);				// Returns the left kerning value
	long GetRKern(void);				// Returns the right kerning value
	int GetHeader(CLongList *, long);	// Obtains a header from a CLongList
	long Add(CLongList *, long);		// Adds a header to a CLongList
	void SetHeader(long=0, long=0, long=0, long=0, long=0,
				   long=0, long=0, long=0, long = 0);
										// Assigns values to a header


	/*** 1.0036 DAN 9.6.98 GRAPHIC MEMORY REVISE ***/
	int GetSymbolHeader(long *);
	/***********************************************/

//Operators
public:
	void operator =(const ClGHeader& headerSrc);
										// Assignment operator
	/*** 1.0046 DAN 10.7.98 GRAPHIC MEM SAVE ***/
	void WriteHeader(CFile *pFile);
	void ReadHeader(CFile *pFile);
	/*******************************************/
};

#endif

