// Header file for CPref class
//
// American LaserWare, Inc
// Pat Summers
// 24 OCT 97
//
/****
	The CPref class is used to store and implement user
	specified preferences for the GUI including the
	color scheme, mouse controls, snap settings, etc.
****/
//
//////////////////////////////

// pref.h

#ifndef CPREF
#define CPREF

// Include version info
#ifdef _ALIUSE
	#include ".\Versions\Versions.h"
	#include ".\WSData\Layer.h"
	#include ".\WSData\Item.h"
	#include ".\Grid.h"
	#include ".\Winscribe.h"
#else
	#include "Versions.h"
	#include "Layer.h"
	#include "Item.h"
	#include "Grid.h"
#endif

/***************************************/
// Class specific constant definitions
#define	PREF_DEF_FILENAME	_T("default.pre")

//// 1.0431 PAT 08.09.00 LAZ FILE RECOVERY ////
#define PREF_AUTOSAVE_NAME	_T("AUTOSAVE.LAZ")
//// 1.0431 ///////////////////////////////////

//// 1.0447 PAT 18.10.00 TTF SPACE SIZE ////
const double PREF_TTFSPACEFACTOR_MIN		=	0.01;
const double PREF_TTFSPACEFACTOR_MAX		=	2.00;
const double PREF_TTFSPACEFACTOR_DEFAULT	=	1.00;
//// 1.0447 ////////////////////////////////

//// 1.1241 PAT 31.10.06 NUDGE SIZE ////
const int		PREF_NUDGE_MODE_ACCEL		=	0;
const int		PREF_NUDGE_MODE_FIXED		=	1;
const double	PREF_NUDGE_FIXED_MIN		=	0.0001;
//// 1.1241 ////////////////////////////

//// 1.1287 PAT 24.01.07 MRU LENGTH ADJUST ////
const int		PREF_MRU_SIZE_DEFAULT		=	4;
const int		PREF_MRU_SIZE_MIN			=	1;
const int		PREF_MRU_SIZE_MAX			=	15;
//// 1.1287 ///////////////////////////////////

//// PS090923A SPEED CONTROL IN SIMULATE ////
const int		PREF_SIM_SPEED_MODE_NOTIME	=	0;
const int		PREF_SIM_SPEED_MODE_TIMED	=	1;

const int		PREF_SIM_SPEED_MODE_DEFAULT	=	PREF_SIM_SPEED_MODE_NOTIME;
	// Preserve original behavior

const double	PREF_SIM_SPEED_FACTOR_DEFAULT	=	0.0;
const double	PREF_SIM_SPEED_FACTOR_MIN		=	0.01;
const double	PREF_SIM_SPEED_FACTOR_MAX		=	100.0;
//// PS090923A //////////////////////////////

//// PS091002A SIMULATE SPEED FINISH ////
const double	PREF_SIM_SPEED_FACTOR_FASTEST	=	0.0;
const double	PREF_SIM_SPEED_FACTOR_B1		=	1.0;
const double	PREF_SIM_SPEED_FACTOR_B2		=	0.5;
const double	PREF_SIM_SPEED_FACTOR_B5		=	0.2;
const double	PREF_SIM_SPEED_FACTOR_B10		=	0.1;
const double	PREF_SIM_SPEED_FACTOR_B20		=	0.05;
const double	PREF_SIM_SPEED_FACTOR_B50		=	0.02;
const double	PREF_SIM_SPEED_FACTOR_B100		=	0.01;

const int		PREF_SIM_SPEED_FACTOR_INDEX_FASTEST		=	0;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B1			=	1;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B2			=	2;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B5			=	3;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B10			=	4;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B20			=	5;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B50			=	6;
const int		PREF_SIM_SPEED_FACTOR_INDEX_B100		=	7;


const int		PREF_SIM_SPEED_FACTOR_INDEX_MIN			=	PREF_SIM_SPEED_FACTOR_INDEX_FASTEST;
const int		PREF_SIM_SPEED_FACTOR_INDEX_MAX			=	PREF_SIM_SPEED_FACTOR_INDEX_B100;
//// PS091002A //////////////////////////


// CPref class definition
class CPref : public CObject
{

	DECLARE_SERIAL( CPref)

// Attributes
public:
	// Preference version
	UINT
		m_nVersion;
	// Current preference file name
	CString
		m_sPrefFilePath,
		m_sPrefFileTitle,
		m_sPrefFileName,
		m_sPrefFileExt;
	// Stretching mode flag
	UINT	m_bNaturalAspectStretch;

	// Double click flag
	UINT	m_bDoubleClickOpen;

	// Prototype layer with default values
	CLayer
		m_InitLayer;
	// Prototype items for default values
	CItem
		m_aInitItems[CI_NUM_TYPES];

	/*** 1.0063 PAT 30.05.98 PREFERENCES ***/
	// Grid Settings
	CGrid
		m_Grid;
	BOOL
		m_bUsingDefault;
	/***************************************/

	//// 1.0247 PAT 11.11.99 MORE RELOAD ////
	// This is overridden
	//	/*** 1.0223 PAT 03.08.99 NO TEMP GRAPHIC OPTION ***/
	//	BOOL
	//		m_bUseQuickLoad;
	//	/*** 1.0223 ***************************************/
	BOOL
		m_bUseQLGraphics,
		m_bUseQLFonts;
	//// 1.0247 /////////////////////////////

	/// 1.0242 DAN 9/2/99 NEW HATCHFILL ADDITION FIRST REVISION ///
	BOOL	m_bLiveFill;
	////1.0242/////////////////////////////////////////////////////

	//// 1.0431 PAT 08.09.00 LAZ FILE RECOVERY ////
	BOOL
		m_bAutoSaveAfterMark;
	//// 1.0431 ///////////////////////////////////

	//// 1.0447 PAT 18.10.00 TTF SPACE SIZE ////
	double
		m_dTTFSpaceFactor;
	//// 1.0447 ////////////////////////////////
	BOOL
		m_bBlankVar;

	//// 1.0577 PAT 18.07.01 FAUX SDI ////
	BOOL
		m_bSDI;
	//// 1.0577 //////////////////////////

	//// 1.0997 PAT 15.03.05 DEFAULT FOLDERS IN PREF ////
	BOOL m_bUseDefaultFolderLAZ;
	CString m_sDefaultFolderLAZ;
	BOOL m_bUseDefaultFolderMAT;
	CString m_sDefaultFolderMAT;
	BOOL m_bUseDefaultFolderFIX;
	CString m_sDefaultFolderFIX;
	BOOL m_bUseDefaultFolderDXF;
	CString m_sDefaultFolderDXF;
	BOOL m_bUseDefaultFolderFNT;
	CString m_sDefaultFolderFNT;
	//// 1.0997 /////////////////////////////////////////
	
	//// 1.1049 PAT 01.09.05 MARK CONTROL PREFS ////
	int m_iMarkCtrlMarkMode;
	BOOL m_bMarkCtrlAlignment;
	int m_iMarkCtrlNumPartsInRun;
	BOOL m_bMarkCtrlContinuous;
	//// 1.1049 ////////////////////////////////////

	//// 1.1241 PAT 31.10.06 NUDGE SIZE ////
	int m_iNudgeMode;
	double m_dNudgeSize;
	//// 1.1241 ////////////////////////////
	
	//// 1.1287 PAT 24.01.07 MRU LENGTH ADJUST ////
	BOOL m_bMRUSizeDefault;
	int m_iMRUSize;

	BOOL m_bLoadQuietly;
	BOOL m_bLastLoadWasSuccessful;
	//// 1.1287 ///////////////////////////////////

	// Operators
public:
	CPref(void);
	~CPref(void);

	//// 1.0461 PAT 02.11.00 PREF IN DLL - 2 ////
	// Change the function declarations below to
	// include the NAME of the arguments, not
	// just the type
	//// 1.0461 /////////////////////////////////

	void Init(void);
	void Serialize(CArchive& ar);
	CLayer* GetNewLayer(void);
	CItem* GetNewItem(UINT nType);
	/*** 1.0063 PAT 30.05.98 PREFERENCES ***/
	void Open(void);
	void Load(CString *psFileName = NULL);
	void SaveAs(void);
	void Save(CString *psFileName = NULL);
	CString MakeRelative(CString sPath);
	CString MakeAbsolute(CString sPath);
	/***************************************/

	//// 1.0447 PAT 18.10.00 TTF SPACE SIZE ////
	double GetTTFSpaceFactor(void);
	//// 1.0447 ////////////////////////////////

	//// 1.0453 PAT 24.10.00 PREF IN DLL ////
	BOOL SetTTFSpaceFactor(double dFactor);
	//// 1.0453 /////////////////////////////

	//// 1.0493 PAT 24.01.01 DEFAULT OBJECT VALUES ////
	BOOL GetDefaultItem(UINT nType, CObject *pItem);
	BOOL SetDefaultItem(CObject *pItem);
	void ApplyPrefOverrides(CItem *pItem);
	//// 1.0493 ///////////////////////////////////////

	//// 1.0997 PAT 15.03.05 DEFAULT FOLDERS IN PREF ////
	BOOL GetUseDefaultFolderLAZ(void);
	void SetUseDefaultFolderLAZ(BOOL bUse);
	CString GetDefaultFolderLAZ(void);
	void SetDefaultFolderLAZ(CString sFolder);

	BOOL GetUseDefaultFolderMAT(void);
	void SetUseDefaultFolderMAT(BOOL bUse);
	CString GetDefaultFolderMAT(void);
	void SetDefaultFolderMAT(CString sFolder);
	
	BOOL GetUseDefaultFolderFIX(void);
	void SetUseDefaultFolderFIX(BOOL bUse);
	CString GetDefaultFolderFIX(void);
	void SetDefaultFolderFIX(CString sFolder);

	BOOL GetUseDefaultFolderDXF(void);
	void SetUseDefaultFolderDXF(BOOL bUse);
	CString GetDefaultFolderDXF(void);
	void SetDefaultFolderDXF(CString sFolder);

	BOOL GetUseDefaultFolderFNT(void);
	void SetUseDefaultFolderFNT(BOOL bUse);
	CString GetDefaultFolderFNT(void);
	void SetDefaultFolderFNT(CString sFolder);

	//// 1.0997 /////////////////////////////////////////

	//// 1.1241 PAT 31.10.06 NUDGE SIZE ////
	int GetNudgeMode(void);
	int SetNudgeMode(int iMode);
	double GetNudgeSize(void);
	double SetNudgeSize(double dSize);

	
	// equate operator =
	void operator =( const CPref& src );
	// equivalence operator ==
	BOOL operator ==( const CPref& src );
	//// 1.1241 ////////////////////////////

	//// 1.1287 PAT 24.01.07 MRU LENGTH ADJUST ////
	BOOL IsMRUSizeDefault(void);
	void SetMRUSizeDefault(BOOL bUse);
	int GetMRUSize(void);
	void SetMRUSize(int iSize);

	BOOL LoadQuietly(void);
	//// 1.1287 ///////////////////////////////////

	//// 1.1377 PAT 27.08.07 DEFAULT LAYER SETTINGS FROM PREF ////
	BOOL GetDefaultLayer(CObject *pLayer);
	BOOL SetDefaultLayer(CObject *pLayer);
	//// 1.1377 //////////////////////////////////////////////////

	//// JT080505A Adding Language Selection Option ////
	CString m_sLanguage;
	//// JT080505A ////

	//// PS090923A SPEED CONTROL IN SIMULATE ////
protected:
	int m_iSimSpeedMode;
	double m_dSimSpeedFactor;
public:
	int GetSimSpeedMode(void);
	void SetSimSpeedMode(int iMode);
	double GetSimSpeedFactor(void);
	void SetSimSpeedFactor(double dFactor);
	//// PS090923A //////////////////////////////
	//// PS091002A SIMULATE SPEED FINISH ////
protected:
	int SimSpeedIndexFromFactor(double dFactor);
	double SimSpeedFactorFromIndex(int iIndex);
public:
	int GetSimSpeedFactorIndex(void);
	void SetSimSpeedFactorIndex(int iIndex);
	//// PS091002A //////////////////////////

};

#endif

