// Header file for CWorldMap class
//
// American LaserWare, Inc
// Pat Summers
// 19 AUG 1997
//
//	The CWorldMap class provides the functionality of
//	using both relative and absolute vector commands
//	when rendering an image.  It maintains its current
//	absolute position and the relative displacement
//	from the previous position.  Location changes can
//	be made by relative or absolute vector displacements
//	using both ClGVector and CldGvector structures and the
//	maximum displacement from any location by a following
//	set of vectors is monitored.
///////////////////////////////////////////////////////////

// worldmap.h

#ifndef WORLDMAP
#define WORLDMAP

// Include header files required for members
#include "vgconst.h"
#include "lgvector.h"
#include "ldgvecto.h"

class CWorldMap : public CObject
{

	DECLARE_SERIAL (CWorldMap)

//Attributes
public:
	long double m_ldX1,
				m_ldX2,
				m_ldY1,
				m_ldY2,
				m_ldDX,
				m_ldDY,
				m_ldXMax,
				m_ldYMax,
				m_ldXMin,
				m_ldYMin;
				
	long m_lX1,
		 m_lX2,
		 m_lY1,
		 m_lY2,
		 m_lDX,
		 m_lDY;

public:
// Operations
// Implememtations
	CWorldMap();						// Constructor
	~CWorldMap();						// Destructor
	void Init(void);					// Initializes members
	void Serialize(CArchive&);			// Load / Save routines
	void LocateBy(long double, long double);
	void LocateBy(CldGVector);
	void LocateBy(long,long);
	void LocateBy(ClGVector);			// Determines location after
											// relative displacement
	void LocateTo(long double,long double);
	void LocateTo(CldGVector);
	void LocateTo(long,long);
	void LocateTo(ClGVector);			// Sets location to an absolute
											// position
	void Update(void);					// Makes new position the old
											// one after a movement	
	void UpdateExtents(void);			// Monitors size of a drawing
	void ResetExtents(void);			// Sets extent values to the
											// current position
	void Origin(void);					// Sets the location to origin

};

#endif


